<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0" 
xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
xmlns:xs="http://www.w3.org/2001/XMLSchema" 
xmlns:fn="http://www.w3.org/2005/xpath-functions"
xmlns:rwe="http://www.rwe.com/gi/ada"
exclude-result-prefixes="xs fn rwe">
	<xsl:output method="xml" version="1.0" encoding="ISO-8859-1" indent="yes"/>

	
	<xsl:template match="EDIFACTINTERCHANGE">
		
		<xsl:variable name="now" select="current-dateTime()"/>
		<xsl:variable name="nachrichtennummer" select="concat('A', format-dateTime($now,	'[Y02][M01][D01][H01][m01][s01]'), substring(format-dateTime($now, '[f01]'), 1, 1))"/>
		
		<root>
	
		<infos>
			<absender><xsl:value-of select="S_UNB/C_S003/D_0010"/></absender>
			<empfaenger><xsl:value-of select="S_UNB/C_S002/D_0004"/></empfaenger>
			<nachrichtennummer><xsl:value-of select="$nachrichtennummer"/></nachrichtennummer>
			<referenznummer><xsl:value-of select="S_UNB/D_0020"/></referenznummer>
			<nowDTM><xsl:value-of select="format-dateTime($now, '[Y0002][M01][D01][H01][m01]')"/></nowDTM>
		</infos>

		<fehler>
		<xsl:variable name="counterUNA" select="count(S_UNA)"/>
		<xsl:variable name="counterUNB" select="count(S_UNB)"/>
		<xsl:variable name="counterUNZ" select="count(S_UNZ)"/>

		<!-- UNA prüfen -->
		<xsl:if test="counterUNA &gt; 1">
			<xsl:choose>
				<xsl:when test="count(S_UNA/child::*) &lt; 6">
					<xsl:call-template name="Fehler">
						<xsl:with-param name="code" select="13"/>
						<xsl:with-param name="segment" select="'UNA'"/>							
						<xsl:with-param name="gruppenposition" select="count(S_UNA/child::*)+1"/>
					</xsl:call-template>	
				</xsl:when>
				<xsl:when test="count(S_UNA/child::*) &gt; 6">
					<xsl:call-template name="Fehler">
						<xsl:with-param name="code" select="16"/>
						<xsl:with-param name="segment" select="'UNA'"/>
						<xsl:with-param name="gruppenposition" select="8"/>
					</xsl:call-template>	
				</xsl:when>				
			</xsl:choose>
					
			<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="S_UNA/D_UNA1"/>
					<xsl:with-param name="segment" select="'UNA'"/>
					<xsl:with-param name="gruppenposition" select="2"/>
			</xsl:call-template>	
		    <xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="S_UNA/D_UNA2"/>
					<xsl:with-param name="segment" select="'UNA'"/>
					<xsl:with-param name="gruppenposition" select="3"/>
			</xsl:call-template>	
		    <xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="S_UNA/D_UNA3"/>
					<xsl:with-param name="segment" select="'UNA'"/>
					<xsl:with-param name="gruppenposition" select="4"/>
			</xsl:call-template>	
		    <xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="S_UNA/D_UNA4"/>
					<xsl:with-param name="segment" select="'UNA'"/>
					<xsl:with-param name="gruppenposition" select="5"/>
			</xsl:call-template>	
		    <xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="S_UNA/D_UNA5"/>
					<xsl:with-param name="segment" select="'UNA'"/>
					<xsl:with-param name="gruppenposition" select="6"/>
			</xsl:call-template>	
		    <xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="S_UNA/D_UNA6"/>
					<xsl:with-param name="segment" select="'UNA'"/>
					<xsl:with-param name="gruppenposition" select="7"/>
			</xsl:call-template>		
		</xsl:if>		
				
		<!-- UNB prüfen -->
		<xsl:choose>
			<xsl:when test="$counterUNB = 0">
				<xsl:call-template name="Fehler">
					<xsl:with-param name="code" select="13"/>
					<xsl:with-param name="segment" select="'UNB'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="$counterUNB = 1">
				<xsl:if test="S_UNB/C_S001/D_0001 != 'UNOC'">
					<xsl:call-template name="Fehler">
						<xsl:with-param name="code" select="2"/>
						<xsl:with-param name="segment" select="'UNB'"/>
						<xsl:with-param name="gruppenposition" select="2"/>
						<xsl:with-param name="elementposition" select="1"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="S_UNB/C_S001/D_0002 != '3'">
					<xsl:call-template name="Fehler">
						<xsl:with-param name="code" select="2"/>
						<xsl:with-param name="segment" select="'UNB'"/>
						<xsl:with-param name="gruppenposition" select="2"/>
						<xsl:with-param name="elementposition" select="2"/>
					</xsl:call-template>
				</xsl:if>				
		<!--		<xsl:if test="S_UNB/C_S003/D_0010 != $empfaenger">
					<xsl:call-template name="Fehler">
						<xsl:with-param name="code" select="7"/>
						<xsl:with-param name="segment" select="'UNB'"/>
						<xsl:with-param name="gruppenposition" select="count(S_UNB/C_S003/preceding-sibling::*)+1"/>
						<xsl:with-param name="elementposition" select="count(S_UNB/C_S003/D_0010/preceding-sibling::*)+1"/>
					</xsl:call-template>
				</xsl:if>
	-->
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="S_UNB/C_S002/D_0004"/>
					<xsl:with-param name="segment" select="'UNB'"/>
					<xsl:with-param name="gruppenposition" select="3"/>
					<xsl:with-param name="elementposition" select="1"/>
				</xsl:call-template>
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="S_UNB/C_S002/D_0007"/>
					<xsl:with-param name="segment" select="'UNB'"/>
					<xsl:with-param name="wertebereich" select="'14,500,501,502,ZZZ'"/>
					<xsl:with-param name="gruppenposition" select="3"/>
					<xsl:with-param name="elementposition" select="2"/>
				</xsl:call-template>	
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="S_UNB/C_S003/D_0010"/>
					<xsl:with-param name="segment" select="'UNB'"/>
					<xsl:with-param name="gruppenposition" select="4"/>
					<xsl:with-param name="elementposition" select="1"/>
				</xsl:call-template>
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="S_UNB/C_S003/D_0007"/>
					<xsl:with-param name="segment" select="'UNB'"/>
					<xsl:with-param name="wertebereich" select="'14,500,501,502,ZZZ'"/>
					<xsl:with-param name="gruppenposition" select="4"/>
					<xsl:with-param name="elementposition" select="2"/>
				</xsl:call-template>			
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="S_UNB/C_S004/D_0017"/>
					<xsl:with-param name="segment" select="'UNB'"/>
					<xsl:with-param name="gruppenposition" select="5"/>
					<xsl:with-param name="elementposition" select="1"/>
				</xsl:call-template>		
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="S_UNB/C_S004/D_0019"/>
					<xsl:with-param name="segment" select="'UNB'"/>
					<xsl:with-param name="gruppenposition" select="5"/>
					<xsl:with-param name="elementposition" select="2"/>
				</xsl:call-template>		
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="S_UNB/D_0020"/>
					<xsl:with-param name="segment" select="'UNB'"/>
					<xsl:with-param name="gruppenposition" select="6"/>
				</xsl:call-template>													
			</xsl:when>			
		</xsl:choose>
	
	
		<!-- UNZ prüfen -->
		<xsl:choose>
			<xsl:when test="$counterUNZ = 0">
				<xsl:call-template name="Fehler">
					<xsl:with-param name="code" select="13"/>
					<xsl:with-param name="segment" select="'UNZ'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="$counterUNZ = 1">
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="S_UNZ/D_0036"/>
					<xsl:with-param name="segment" select="'UNZ'"/>
					<xsl:with-param name="gruppenposition" select="2"/>
				</xsl:call-template>		
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="S_UNZ/D_0020"/>
					<xsl:with-param name="segment" select="'UNZ'"/>
					<xsl:with-param name="gruppenposition" select="3"/>
				</xsl:call-template>						
				<xsl:variable name="anzahlNachrichten" select="count(M_ORDERS/S_UNH)"/>
				<xsl:if test="$anzahlNachrichten != S_UNZ/D_0036">
					<xsl:call-template name="Fehler">
						<xsl:with-param name="code" select="29"/>
						<xsl:with-param name="gruppenposition" select="2"/>
						<xsl:with-param name="segment" select="'UNZ'"/>
					</xsl:call-template>
				</xsl:if>				
			</xsl:when>			
		</xsl:choose>

		<!-- Prüfreferenzen UNB und UNZ vergleichen -->
		<xsl:if test="S_UNB/D_0020 != S_UNZ/D_0020">
			<xsl:call-template name="Fehler">
				<xsl:with-param name="code" select="28"/>
				<xsl:with-param name="gruppenposition" select="3"/>
				<xsl:with-param name="segment" select="'UNZ'"/>
			</xsl:call-template>
		</xsl:if>
		
		<!-- Prüfen ob UNHs enthalten sind -->
		<xsl:if test="count(M_ORDERS/S_UNH) = 0">
			<xsl:call-template name="Fehler">
				<xsl:with-param name="code" select="32"/>
				<xsl:with-param name="segment" select="'UNB'"/>
			</xsl:call-template>
		</xsl:if>

		<!-- Prüfen ob UNHs und UNTs vorhanden sind -->
		<xsl:variable name="counterUNH" select="count(M_ORDERS/S_UNH)"/>
		<xsl:variable name="counterUNT" select="count(M_ORDERS/S_UNT)"/>
		
		<xsl:if test="$counterUNH = 0">
			<xsl:call-template name="Fehler">
				<xsl:with-param name="code" select="13"/>
				<xsl:with-param name="segment" select="'UNH'"/>
			</xsl:call-template>
		</xsl:if>
				
		<xsl:if test="$counterUNT = 0">
			<xsl:call-template name="Fehler">
				<xsl:with-param name="code" select="13"/>
				<xsl:with-param name="segment" select="'UNH'"/>
			</xsl:call-template>
		</xsl:if>
		
		
		<xsl:for-each select="M_ORDERS">
			<nachricht>
			<xsl:attribute name="idUNH" select="S_UNH/D_0062"/>
			<xsl:attribute name="nachrichtenkennung" select="S_UNH/C_S009/D_0065"/>
			<xsl:attribute name="freigabenummer" select="S_UNH/C_S009/D_0054"/>
			<xsl:attribute name="versionsnummer" select="S_UNH/C_S009/D_0052"/>
			<!-- UNH prüfen -->
			<xsl:call-template name="PruefeFeld">
				<xsl:with-param name="knoten" select="S_UNH/D_0062"/>
				<xsl:with-param name="segment" select="'UNH'"/>
				<xsl:with-param name="max" select="14"/>
				<xsl:with-param name="gruppenposition" select="2"/>
			</xsl:call-template>	
			<xsl:call-template name="PruefeFeld">
				<xsl:with-param name="knoten" select="S_UNH/C_S009/D_0065"/>
				<xsl:with-param name="segment" select="'UNH'"/>
				<xsl:with-param name="max" select="6"/>
				<xsl:with-param name="wertebereich" select="'ORDERS'"/>
				<xsl:with-param name="gruppenposition" select="3"/>
				<xsl:with-param name="elementposition" select="1"/>
			</xsl:call-template>				
			<xsl:call-template name="PruefeFeld">
				<xsl:with-param name="knoten" select="S_UNH/C_S009/D_0052"/>
				<xsl:with-param name="segment" select="'UNH'"/>
				<xsl:with-param name="max" select="3"/>
				<xsl:with-param name="wertebereich" select="'D'"/>
				<xsl:with-param name="gruppenposition" select="3"/>
				<xsl:with-param name="elementposition" select="2"/>
			</xsl:call-template>				
			<xsl:call-template name="PruefeFeld">
				<xsl:with-param name="knoten" select="S_UNH/C_S009/D_0054"/>
				<xsl:with-param name="segment" select="'UNH'"/>
				<xsl:with-param name="max" select="3"/>
				<xsl:with-param name="wertebereich" select="'09B'"/>
				<xsl:with-param name="gruppenposition" select="3"/>
				<xsl:with-param name="elementposition" select="3"/>
			</xsl:call-template>				
			<xsl:call-template name="PruefeFeld">
				<xsl:with-param name="knoten" select="S_UNH/C_S009/D_0051"/>
				<xsl:with-param name="segment" select="'UNH'"/>
				<xsl:with-param name="max" select="2"/>
				<xsl:with-param name="wertebereich" select="'UN'"/>
				<xsl:with-param name="gruppenposition" select="3"/>
				<xsl:with-param name="elementposition" select="4"/>
			</xsl:call-template>				
			<xsl:call-template name="PruefeFeld">
				<xsl:with-param name="knoten" select="S_UNH/C_S009/D_0057"/>
				<xsl:with-param name="segment" select="'UNH'"/>
				<xsl:with-param name="max" select="6"/>
				<xsl:with-param name="wertebereich" select="'1.1i'"/>
				<xsl:with-param name="gruppenposition" select="3"/>
				<xsl:with-param name="elementposition" select="5"/>
			</xsl:call-template>																
			
			<!-- UNT prüfen -->		
			<xsl:call-template name="PruefeFeld">
				<xsl:with-param name="knoten" select="S_UNT/D_0074"/>
				<xsl:with-param name="max" select="6"/>
				<xsl:with-param name="segment" select="'UNT'"/>
				<xsl:with-param name="gruppenposition" select="2"/>
			</xsl:call-template>		
			<xsl:call-template name="PruefeFeld">
				<xsl:with-param name="knoten" select="S_UNT/D_0062"/>
				<xsl:with-param name="max" select="14"/>
				<xsl:with-param name="segment" select="'UNT'"/>
				<xsl:with-param name="gruppenposition" select="3"/>
			</xsl:call-template>						
			
			<!-- Prüfreferenzen UNH und UNT vergleichen -->
			<xsl:if test="S_UNH/D_0062 != S_UNT/D_0062">
				<xsl:call-template name="Fehler">
					<xsl:with-param name="code" select="28"/>
					<xsl:with-param name="gruppenposition" select="3"/>
					<xsl:with-param name="segment" select="'UNT'"/>
				</xsl:call-template>
			</xsl:if>
		
			<!-- Anzahl Segmente prüfen -->
			<xsl:if test="count(descendant::*[substring(name(), 1, 2)='S_' and name() != 'S_UNB' and name() != 'S_UNA' and name() != 'S_UNZ']) != S_UNT/D_0074">
				<xsl:call-template name="Fehler">
					<xsl:with-param name="code" select="29"/>
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="segment" select="'UNT'"/>
				</xsl:call-template>
			</xsl:if>

			
			<!-- BGM prüfen -->
			<xsl:variable name="counterBGM" select="count(S_BGM)"/>
			
			<xsl:choose>
				<xsl:when test="$counterBGM = 0">
					<xsl:call-template name="Fehler">
						<xsl:with-param name="code" select="13"/>
						<xsl:with-param name="segmentposition" select="$counterUNH"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:when test="$counterBGM &gt; 1">
					<xsl:call-template name="Fehler">
						<xsl:with-param name="code" select="35"/>
						<xsl:with-param name="segmentposition" select="$counterUNH+2"/>
					</xsl:call-template>
				</xsl:when>				
				<xsl:otherwise>
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="S_BGM/C_C002/D_1001"/>
						<xsl:with-param name="max" select="3"/>
						<xsl:with-param name="wertebereich" select="'7,E40,Z05,Z10,Z11,Z12,Z14,Z19,Z24,Z27,Z28,Z29,Z30,Z31,Z34'"/>
						<xsl:with-param name="gruppenposition" select="2"/>
						<xsl:with-param name="elementposition" select="1"/>
						<xsl:with-param name="segmentknoten" select="S_BGM"/>
					</xsl:call-template>		
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="S_BGM/C_C106/D_1004"/>
						<xsl:with-param name="max" select="70"/>
						<xsl:with-param name="gruppenposition" select="3"/>
						<xsl:with-param name="elementposition" select="1"/>
						<xsl:with-param name="segmentknoten" select="S_BGM"/>
					</xsl:call-template>			
				</xsl:otherwise>
			</xsl:choose>
			
			<!-- DTM prüfen -->
			<xsl:variable name="counterDTM_137" select="count(S_DTM[C_C507/D_2005='137'])"/>
			<xsl:variable name="counterDTM" select="count(S_DTM)"/>
			
			<xsl:choose>
				<xsl:when test="$counterDTM_137 = 0">
					<xsl:call-template name="Fehler">
						<xsl:with-param name="segmentposition" select="$counterUNH+$counterBGM"/>
						<xsl:with-param name="code" select="13"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:when test="$counterDTM &gt; 4">
					<xsl:call-template name="Fehler">
						<xsl:with-param name="segmentposition" select="$counterUNH+$counterBGM+5"/>
						<xsl:with-param name="code" select="35"/>
					</xsl:call-template>
				</xsl:when>				
				<xsl:otherwise>
					<xsl:for-each select="S_DTM">
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="C_C507/D_2005"/>
							<xsl:with-param name="max" select="3"/>
							<xsl:with-param name="wertebereich" select="'137,203,Z02,273'"/>
							<xsl:with-param name="gruppenposition" select="2"/>
							<xsl:with-param name="elementposition" select="1"/>
							<xsl:with-param name="segmentknoten" select="."/>
						</xsl:call-template>		
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="C_C507/D_2380"/>
							<xsl:with-param name="max" select="35"/>
							<xsl:with-param name="gruppenposition" select="2"/>
							<xsl:with-param name="elementposition" select="2"/>
							<xsl:with-param name="segmentknoten" select="."/>
						</xsl:call-template>	
						<xsl:choose>
							<xsl:when test="C_C507/D_2005='137'">
								<xsl:call-template name="PruefeFeld">
									<xsl:with-param name="knoten" select="C_C507/D_2379"/>
									<xsl:with-param name="max" select="3"/>
									<xsl:with-param name="wertebereich" select="'203'"/>
									<xsl:with-param name="gruppenposition" select="2"/>
									<xsl:with-param name="elementposition" select="3"/>
									<xsl:with-param name="segmentknoten" select="."/>
								</xsl:call-template>
							</xsl:when>								
							<xsl:when test="C_C507/D_2005='203' or C_C507/D_2005='Z02'">
								<xsl:call-template name="PruefeFeld">
									<xsl:with-param name="knoten" select="C_C507/D_2379"/>
									<xsl:with-param name="max" select="3"/>
									<xsl:with-param name="wertebereich" select="'102'"/>
									<xsl:with-param name="gruppenposition" select="2"/>
									<xsl:with-param name="elementposition" select="3"/>
									<xsl:with-param name="segmentknoten" select="."/>
								</xsl:call-template>
							</xsl:when>
						</xsl:choose>
					</xsl:for-each>												
				</xsl:otherwise>
			</xsl:choose>
			
			<!-- IMD prüfen -->
			<xsl:variable name="counterIMD" select="count(S_IMD)"/>
			
			<xsl:if test="$counterIMD &gt; 3">
				<xsl:call-template name="Fehler">
					<xsl:with-param name="segmentposition" select="$counterUNH+$counterBGM+$counterDTM+4"/>
					<xsl:with-param name="code" select="35"/>
				</xsl:call-template>
			</xsl:if>
			<xsl:for-each select="S_IMD">
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C272/D_7081"/>
					<xsl:with-param name="max" select="3"/>
					<xsl:with-param name="wertebereich" select="'Z01,Z02,Z03,Z07,Z08,Z10,Z11,Z12,Z13,Z14,Z35'"/>
					<xsl:with-param name="gruppenposition" select="3"/>
					<xsl:with-param name="elementposition" select="1"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>		
				<xsl:if test="C_C272/D_7081='Z14'">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="C_C273/D_7009"/>
						<xsl:with-param name="max" select="17"/>
						<xsl:with-param name="wertebereich" select="'Z06,Z07'"/>
						<xsl:with-param name="gruppenposition" select="3"/>
						<xsl:with-param name="elementposition" select="1"/>
						<xsl:with-param name="segmentknoten" select="."/>
					</xsl:call-template>						
				</xsl:if>
			</xsl:for-each>


			<!-- RFF prüfen -->
			<xsl:variable name="counterRFF_PI" select="count(G_ORDERS_SG1/S_RFF[C_C506/D_1153='Z13'])"/>
			<xsl:variable name="counterRFF" select="count(G_ORDERS_SG1/S_RFF)"/>
			
			
			<xsl:choose>
				<xsl:when test="$counterRFF_PI = 0">
					<xsl:call-template name="Fehler">
						<xsl:with-param name="segmentposition" select="$counterUNH+$counterBGM+$counterDTM+$counterIMD"/>
						<xsl:with-param name="code" select="13"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:when test="$counterRFF &gt; 2">
					<xsl:call-template name="Fehler">
						<xsl:with-param name="segmentposition" select="$counterUNH+$counterBGM+$counterDTM+$counterIMD+3"/>
						<xsl:with-param name="code" select="35"/>
					</xsl:call-template>
				</xsl:when>
			</xsl:choose>	
			<xsl:for-each select="G_ORDERS_SG1/S_RFF">
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C506/D_1153"/>
					<xsl:with-param name="max" select="3"/>
					<xsl:with-param name="wertebereich" select="'Z13,AAG,ACW'"/>
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="elementposition" select="1"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>		
				<xsl:choose>
					<xsl:when test="C_C506/D_1153='Z13'">
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="C_C506/D_1154"/>
							<xsl:with-param name="min" select="5"/>
							<xsl:with-param name="max" select="5"/>
							<xsl:with-param name="gruppenposition" select="2"/>
							<xsl:with-param name="elementposition" select="2"/>
							<xsl:with-param name="segmentknoten" select="."/>
							<xsl:with-param name="zeichenart" select="'n'"/>		
						</xsl:call-template>	
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="C_C506/D_1154"/>
							<xsl:with-param name="max" select="70"/>
							<xsl:with-param name="gruppenposition" select="2"/>
							<xsl:with-param name="elementposition" select="2"/>
							<xsl:with-param name="segmentknoten" select="."/>
						</xsl:call-template>				
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
			
			<!-- DTM SG1 prüfen -->
			<xsl:variable name="counterDTM_SG1" select="count(G_ORDERS_SG1/S_DTM)"/>
			
			<xsl:choose>
				<xsl:when test="$counterDTM_SG1 &gt; 1">
					<xsl:call-template name="Fehler">
						<xsl:with-param name="segmentposition" select="$counterUNH+$counterBGM+$counterDTM+$counterIMD+$counterRFF+2"/>
						<xsl:with-param name="code" select="35"/>
					</xsl:call-template>
				</xsl:when>				
			</xsl:choose>
			<xsl:for-each select="G_ORDERS_SG1/S_DTM">
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C507/D_2005"/>
					<xsl:with-param name="max" select="3"/>
					<xsl:with-param name="wertebereich" select="'171'"/>
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="elementposition" select="1"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>		
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C507/D_2380"/>
					<xsl:with-param name="max" select="35"/>
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="elementposition" select="2"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>	
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C507/D_2379"/>
					<xsl:with-param name="max" select="3"/>
					<xsl:with-param name="wertebereich" select="'203'"/>
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="elementposition" select="3"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>
			</xsl:for-each>												
										
			<!-- NAD prüfen -->
			<xsl:variable name="counterNAD" select="count(G_ORDERS_SG2/S_NAD)"/>
			<xsl:variable name="counterCTA" select="count(G_ORDERS_SG2/G_ORDERS_SG5/S_CTA)"/>
			<xsl:variable name="counterCOM" select="count(G_ORDERS_SG2/G_ORDERS_SG5/S_COM)"/>

			<xsl:if test="not(G_ORDERS_SG2/S_NAD[D_3035='MS'])">
				<xsl:call-template name="Fehler">
					<xsl:with-param name="segmentposition" select="$counterUNH+$counterBGM+$counterDTM+$counterRFF+$counterDTM_SG1"/>
					<xsl:with-param name="code" select="13"/>
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="not(G_ORDERS_SG2/S_NAD[D_3035='MR'])">
				<xsl:call-template name="Fehler">
					<xsl:with-param name="segmentposition" select="$counterUNH+$counterBGM+$counterDTM+$counterRFF+$counterDTM_SG1+$counterCTA+$counterCOM"/>
					<xsl:with-param name="code" select="13"/>
				</xsl:call-template>
			</xsl:if>		
									
			<xsl:for-each select="G_ORDERS_SG2/S_NAD">
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="D_3035"/>
					<xsl:with-param name="max" select="3"/>
					<xsl:with-param name="wertebereich" select="'MS,MR,DP,Z03,UD'"/>
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>			
				<xsl:choose>
					<xsl:when test="D_3035='MR' or D_3035='MS'">
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="C_C082/D_3039"/>
							<xsl:with-param name="max" select="35"/>
							<xsl:with-param name="gruppenposition" select="3"/>
							<xsl:with-param name="elementposition" select="1"/>
							<xsl:with-param name="segmentknoten" select="."/>
						</xsl:call-template>					
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="C_C082/D_3055_1"/>
							<xsl:with-param name="max" select="3"/>
							<xsl:with-param name="wertebereich" select="'9,293,305,321,332'"/>
							<xsl:with-param name="gruppenposition" select="3"/>
							<xsl:with-param name="elementposition" select="3"/>
							<xsl:with-param name="segmentknoten" select="."/>
						</xsl:call-template>			
					</xsl:when>
					<xsl:when test="D_3035='Z03'">
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="D_3164"/>
							<xsl:with-param name="max" select="35"/>
							<xsl:with-param name="gruppenposition" select="7"/>
							<xsl:with-param name="segmentknoten" select="."/>
						</xsl:call-template>					
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="D_3251"/>
							<xsl:with-param name="max" select="17"/>
							<xsl:with-param name="gruppenposition" select="9"/>
							<xsl:with-param name="segmentknoten" select="."/>
						</xsl:call-template>	
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="D_3207"/>
							<xsl:with-param name="max" select="3"/>
							<xsl:with-param name="gruppenposition" select="10"/>
							<xsl:with-param name="segmentknoten" select="."/>
						</xsl:call-template>									
					</xsl:when>		
					<xsl:when test="D_3035='UD'">
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="C_C080/D_3045"/>
							<xsl:with-param name="max" select="3"/>
							<xsl:with-param name="gruppenposition" select="4"/>
							<xsl:with-param name="elementposition" select="6"/>
							<xsl:with-param name="segmentknoten" select="."/>
							<xsl:with-param name="pflichtfeld" select="false()"/>
						</xsl:call-template>					
					</xsl:when>										
				</xsl:choose>
			</xsl:for-each>	


			<xsl:choose>
				<xsl:when test="G_ORDERS_SG2[S_NAD/D_3035='MS']/G_ORDERS_SG5/S_CTA">
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="G_ORDERS_SG2[S_NAD/D_3035='MS']/G_ORDERS_SG5/S_CTA/D_3139"/>
						<xsl:with-param name="max" select="3"/>
						<xsl:with-param name="wertebereich" select="'IC'"/>		
						<xsl:with-param name="gruppenposition" select="2"/>
						<xsl:with-param name="elementposition" select="1"/>
						<xsl:with-param name="segmentknoten" select="G_ORDERS_SG2[S_NAD/D_3035='MS']/G_ORDERS_SG5/S_CTA"/>
					</xsl:call-template>	
					<xsl:call-template name="PruefeFeld">
						<xsl:with-param name="knoten" select="G_ORDERS_SG2[S_NAD/D_3035='MS']/G_ORDERS_SG5/S_CTA/C_C056/D_3412"/>
						<xsl:with-param name="max" select="256"/>
						<xsl:with-param name="gruppenposition" select="3"/>
						<xsl:with-param name="elementposition" select="2"/>
						<xsl:with-param name="segmentknoten" select="G_ORDERS_SG2[S_NAD/D_3035='MS']/G_ORDERS_SG5/S_CTA"/>
					</xsl:call-template>									
				</xsl:when>
			</xsl:choose>
			<xsl:choose>
				<xsl:when test="count(G_ORDERS_SG2[S_NAD/D_3035='MS']/G_ORDERS_SG5/S_COM) &gt; 5">
					<xsl:call-template name="Fehler">
						<xsl:with-param name="segmentposition" select="$counterUNH+$counterBGM+$counterDTM+$counterRFF+$counterDTM_SG1+8"/>
						<xsl:with-param name="code" select="35"/>
					</xsl:call-template>
				</xsl:when>					
			</xsl:choose>
			<xsl:for-each select="G_ORDERS_SG2[S_NAD/D_3035='MS']/G_ORDERS_SG5/S_COM">
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C076/D_3148"/>
					<xsl:with-param name="max" select="512"/>
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="elementposition" select="1"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>	
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C076/D_3155"/>
					<xsl:with-param name="max" select="3"/>
					<xsl:with-param name="wertebereich" select="'EM,FX,TE,AJ,AL'"/>
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="elementposition" select="2"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>		
			</xsl:for-each>							
		
			<!-- LOC SG2 prüfen -->
			<xsl:variable name="counterLOC_SG2" select="count(G_ORDERS_SG2/S_LOC)"/>
	
			<xsl:for-each select="G_ORDERS_SG2/S_LOC">
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="D_3227"/>
					<xsl:with-param name="max" select="3"/>
					<xsl:with-param name="wertebereich" select="'107,172'"/>
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>				
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C517/D_3225"/>
					<xsl:with-param name="max" select="35"/>
					<xsl:with-param name="gruppenposition" select="3"/>
					<xsl:with-param name="elementposition" select="1"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>				
			</xsl:for-each>
			
			<!-- RFF SG3 prüfen -->
			<xsl:variable name="counterRFF_SG3" select="count(G_ORDERS_SG2/G_ORDERS_SG3/S_RFF)"/>


			<xsl:for-each select="G_ORDERS_SG2/G_ORDERS_SG3/S_RFF">
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C506/D_1153"/>
					<xsl:with-param name="max" select="3"/>
					<xsl:with-param name="wertebereich" select="'AVC'"/>
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="elementposition" select="1"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>				
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C506/D_1154"/>
					<xsl:with-param name="max" select="70"/>
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="elementposition" select="2"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>						
			</xsl:for-each>		
			
			<!-- CUX prüfen -->
			<xsl:variable name="counterCUX" select="count(G_ORDERS_SG7/S_CUX)"/>
			
			<xsl:if test="$counterCUX &gt; 1">
				<xsl:call-template name="Fehler">
					<xsl:with-param name="segmentposition" select="$counterUNH+$counterBGM+$counterDTM+$counterRFF+$counterDTM_SG1+$counterNAD+$counterCTA+$counterCOM+$counterLOC_SG2+$counterRFF_SG3+2"/>
					<xsl:with-param name="code" select="35"/>
				</xsl:call-template>
			</xsl:if>
			<xsl:for-each select="G_ORDERS_SG7/S_CUX">
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C504/D_6347"/>
					<xsl:with-param name="max" select="3"/>
					<xsl:with-param name="wertebereich" select="'2'"/>
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="elementposition" select="1"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>	
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C504/D_6345"/>
					<xsl:with-param name="max" select="3"/>
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="elementposition" select="2"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>	
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C504/D_6343"/>
					<xsl:with-param name="max" select="3"/>
					<xsl:with-param name="wertebereich" select="'9'"/>
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="elementposition" select="3"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>												
			</xsl:for-each>

			<xsl:apply-templates select="G_ORDERS_SG29"/>

					
			<!-- UNS prüfen -->
			<xsl:variable name="counterUNS" select="count(S_UNS)"/>
	
			<xsl:for-each select="S_UNS">
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="D_0081"/>
					<xsl:with-param name="max" select="1"/>
					<xsl:with-param name="wertebereich" select="'S'"/>
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>				
			</xsl:for-each>
					
			<!--Anzahl Segmente vor UNS (incl) -->
			<xsl:variable name="counterSegmente" select="count(S_UNS/preceding::*[substring(name(), 1, 2)='S_' and name() != 'S_UNB' and name() != 'S_UNA']) + count(S_UNS/ancestor::*[substring(name(), 1, 2)='S_' and name() != 'S_UNB' and name() != 'S_UNA'])+$counterUNS"/>
			
			<!-- MOA prüfen -->
			<xsl:variable name="counterMOA" select="count(S_MOA)"/>
	
			<xsl:if test="$counterMOA &gt; 1">
				<xsl:call-template name="Fehler">
					<xsl:with-param name="segmentposition" select="$counterSegmente+2"/>
					<xsl:with-param name="code" select="35"/>
				</xsl:call-template>
			</xsl:if>				
			<xsl:for-each select="S_MOA">
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C516/D_5025"/>
					<xsl:with-param name="max" select="3"/>
					<xsl:with-param name="wertebereich" select="'24'"/>
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="elementposition" select="1"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>	
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C516/D_5004"/>
					<xsl:with-param name="max" select="35"/>
					<xsl:with-param name="zeichenart" select="'n'"/>
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="elementposition" select="2"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>			
			</xsl:for-each>		
		

			</nachricht>
		
		</xsl:for-each>		
		
		</fehler>

		</root>
	</xsl:template>
		
		<xsl:template match="G_ORDERS_SG29">

			<xsl:variable name="counterSegmente" select="count(preceding::*[substring(name(), 1, 2)='S_' and name() != 'S_UNB' and name() != 'S_UNA']) + count(ancestor::*[substring(name(), 1, 2)='S_' and name() != 'S_UNB' and name() != 'S_UNA'])"/>

			
			<!-- LIN prüfen -->
			<xsl:variable name="counterLIN" select="count(S_LIN)"/>
	
			<xsl:choose>
				<xsl:when test="$counterLIN=0">
					<xsl:call-template name="Fehler">
						<xsl:with-param name="segmentposition" select="$counterSegmente"/>
						<xsl:with-param name="code" select="13"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:when test="$counterLIN &gt; 1">
					<xsl:call-template name="Fehler">
						<xsl:with-param name="segmentposition" select="$counterSegmente+2"/>
						<xsl:with-param name="code" select="35"/>
					</xsl:call-template>
				</xsl:when>			
			</xsl:choose>
			<xsl:for-each select="S_LIN">
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="D_1082"/>
					<xsl:with-param name="max" select="6"/>
					<xsl:with-param name="zeichenart" select="'n'"/>
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C212/D_7140"/>
					<xsl:with-param name="max" select="13"/>
					<xsl:with-param name="zeichenart" select="'n'"/>
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="elementposition" select="2"/>
					<xsl:with-param name="segmentknoten" select="."/>
					<xsl:with-param name="pflichtfeld" select="false()"/>
				</xsl:call-template>
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C212/D_7143"/>
					<xsl:with-param name="max" select="3"/>
					<xsl:with-param name="wertebereich" select="'Z01'"/>
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="elementposition" select="3"/>
					<xsl:with-param name="segmentknoten" select="."/>
					<xsl:with-param name="pflichtfeld" select="false()"/>
				</xsl:call-template>				
			</xsl:for-each>				
			

			<!-- PIA prüfen -->
			<xsl:variable name="counterPIA" select="count(S_PIA)"/>

			<xsl:if test="$counterPIA &gt; 25">
				<xsl:call-template name="Fehler">
					<xsl:with-param name="segmentposition" select="$counterSegmente+$counterLIN+26"/>
					<xsl:with-param name="code" select="35"/>
				</xsl:call-template>
			</xsl:if>	
			<xsl:for-each select="S_PIA">
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="D_4347"/>
					<xsl:with-param name="max" select="3"/>
					<xsl:with-param name="wertebereich" select="'5'"/>		
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>							
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C212_1/D_7140_1"/>
					<xsl:with-param name="max" select="35"/>
					<xsl:with-param name="gruppenposition" select="3"/>
					<xsl:with-param name="elementposition" select="2"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>		
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C212_1/D_7143_1"/>
					<xsl:with-param name="max" select="3"/>
					<xsl:with-param name="wertebereich" select="'SRW'"/>		
					<xsl:with-param name="gruppenposition" select="3"/>
					<xsl:with-param name="elementposition" select="2"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>														
			</xsl:for-each>						
	
	
			<!-- IMD prüfen -->
			<xsl:variable name="counterIMD" select="count(S_IMD)"/>

			<xsl:if test="$counterIMD &gt; 1">
				<xsl:call-template name="Fehler">
					<xsl:with-param name="segmentposition" select="$counterSegmente+$counterLIN+$counterPIA+2"/>
					<xsl:with-param name="code" select="35"/>
				</xsl:call-template>
			</xsl:if>	
					
			<xsl:for-each select="S_IMD">
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C272/D_7081"/>
					<xsl:with-param name="max" select="3"/>
					<xsl:with-param name="wertebereich" select="'Z05'"/>		
					<xsl:with-param name="gruppenposition" select="3"/>
					<xsl:with-param name="elementposition" select="1"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>		
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C273/D_7009"/>
					<xsl:with-param name="max" select="17"/>
					<xsl:with-param name="wertebereich" select="'Z04,Z05'"/>		
					<xsl:with-param name="gruppenposition" select="4"/>
					<xsl:with-param name="elementposition" select="1"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>
			</xsl:for-each>
		

			<!-- QTY SG29 prüfen -->
			<xsl:variable name="counterQTY" select="count(S_QTY)"/>

			<xsl:if test="$counterQTY &gt; 1">
				<xsl:call-template name="Fehler">
					<xsl:with-param name="segmentposition" select="$counterSegmente+$counterLIN+$counterPIA+$counterIMD+2"/>
					<xsl:with-param name="code" select="35"/>
				</xsl:call-template>
			</xsl:if>	
					
			<xsl:for-each select="S_QTY">
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C186/D_6063"/>
					<xsl:with-param name="max" select="3"/>
					<xsl:with-param name="wertebereich" select="'145'"/>		
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="elementposition" select="1"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>		
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C186/D_6060"/>
					<xsl:with-param name="max" select="35"/>
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="elementposition" select="2"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C186/D_6411"/>
					<xsl:with-param name="max" select="3"/>
					<xsl:with-param name="wertebereich" select="'H87'"/>		
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="elementposition" select="3"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>	
			</xsl:for-each>
		
		
			<!-- DTM SG29 prüfen -->
			<xsl:variable name="counterDTM_SG29" select="count(S_DTM)"/>
			
			<xsl:if test="$counterDTM_SG29 &gt; 2">
				<xsl:call-template name="Fehler">
					<xsl:with-param name="segmentposition" select="$counterSegmente+$counterLIN+$counterPIA+$counterIMD+$counterQTY+3"/>
					<xsl:with-param name="code" select="35"/>
				</xsl:call-template>
			</xsl:if>				
			<xsl:for-each select="S_DTM">
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C507/D_2005"/>
					<xsl:with-param name="max" select="3"/>
					<xsl:with-param name="wertebereich" select="'9,163,164'"/>
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="elementposition" select="1"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>		
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C507/D_2380"/>
					<xsl:with-param name="max" select="35"/>
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="elementposition" select="2"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>	
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C507/D_2379"/>
					<xsl:with-param name="max" select="3"/>
					<xsl:with-param name="wertebereich" select="'102,303'"/>
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="elementposition" select="3"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>
			</xsl:for-each>												
			
			<!-- MOA SG29 prüfen -->
			<xsl:variable name="counterMOA_SG29" select="count(S_MOA)"/>
			
			<xsl:if test="$counterMOA_SG29 &gt; 1">
				<xsl:call-template name="Fehler">
					<xsl:with-param name="segmentposition" select="$counterSegmente+$counterLIN+$counterPIA+$counterIMD+$counterQTY+$counterDTM_SG29+2"/>
					<xsl:with-param name="code" select="35"/>
				</xsl:call-template>
			</xsl:if>				
			<xsl:for-each select="S_MOA">
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C516/D_5025"/>
					<xsl:with-param name="max" select="3"/>
					<xsl:with-param name="wertebereich" select="'203'"/>
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="elementposition" select="1"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>		
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C516/D_5004"/>
					<xsl:with-param name="max" select="35"/>
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="elementposition" select="2"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>	
			</xsl:for-each>							


			<!-- FTX prüfen -->
			<xsl:variable name="counterFTX_SG29" select="count(S_FTX)"/>
		
			<xsl:if test="$counterFTX_SG29 &gt; 99">
				<xsl:call-template name="Fehler">
					<xsl:with-param name="segmentposition" select="$counterSegmente+$counterLIN+$counterPIA+$counterIMD+$counterQTY+$counterDTM_SG29+$counterMOA_SG29+100"/>
					<xsl:with-param name="code" select="35"/>
				</xsl:call-template>
			</xsl:if>				
	
			<xsl:for-each select="S_FTX">
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="D_4451"/>
					<xsl:with-param name="max" select="3"/>
					<xsl:with-param name="wertebereich" select="'ACB,Z04,Z05'"/>		
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C108/D_4440_1"/>
					<xsl:with-param name="max" select="512"/>
					<xsl:with-param name="gruppenposition" select="5"/>
					<xsl:with-param name="elementposition" select="1"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>
			</xsl:for-each>
				
					
			<!-- CCI prüfen -->
			<xsl:variable name="counterCCI_SG30" select="count(G_ORDERS_SG30/S_CCI)"/>

			<xsl:if test="$counterCCI_SG30 &gt; 2">
				<xsl:call-template name="Fehler">
					<xsl:with-param name="segmentposition" select="$counterSegmente+$counterLIN+$counterPIA+$counterIMD+$counterQTY+$counterDTM_SG29+$counterMOA_SG29+$counterFTX_SG29+3"/>
					<xsl:with-param name="code" select="35"/>
				</xsl:call-template>
			</xsl:if>				
						
			<xsl:for-each select="G_ORDERS_SG30/S_CCI">
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="D_7059"/>
					<xsl:with-param name="max" select="3"/>
					<xsl:with-param name="wertebereich" select="'ACH,Z02,Z03,Z04,Z05'"/>		
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="segmentknoten" select="."/>
					<xsl:with-param name="pflichtfeld" select="false()"/>			
				</xsl:call-template>		
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="D_7037"/>
					<xsl:with-param name="max" select="3"/>
					<xsl:with-param name="wertebereich" select="'Z77,Z78'"/>		
					<xsl:with-param name="gruppenposition" select="4"/>
					<xsl:with-param name="elementposition" select="1"/>
					<xsl:with-param name="segmentknoten" select="."/>
					<xsl:with-param name="pflichtfeld" select="false()"/>			
				</xsl:call-template>						
				<xsl:choose>
					<xsl:when test="D_7059='ACH'">
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="C_C240/D_7037"/>
							<xsl:with-param name="max" select="17"/>
							<xsl:with-param name="wertebereich" select="'COT,COS,COB'"/>		
							<xsl:with-param name="gruppenposition" select="4"/>
							<xsl:with-param name="elementposition" select="1"/>
							<xsl:with-param name="segmentknoten" select="."/>
						</xsl:call-template>					
					</xsl:when>	
					<xsl:when test="D_7037='Z77'">
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="../S_CAV/C_C889/D_7111"/>
							<xsl:with-param name="max" select="3"/>
							<xsl:with-param name="wertebereich" select="'Z38,Z39'"/>	
							<xsl:with-param name="gruppenposition" select="2"/>
							<xsl:with-param name="elementposition" select="1"/>
							<xsl:with-param name="segmentknoten" select="."/>
						</xsl:call-template>				
					</xsl:when>	
					<xsl:when test="D_7037='Z78'">
						<xsl:call-template name="PruefeFeld">
							<xsl:with-param name="knoten" select="../S_CAV/C_C889/D_7111"/>
							<xsl:with-param name="max" select="3"/>
							<xsl:with-param name="wertebereich" select="'Z41,Z42,Z43,Z60,Z67'"/>	
							<xsl:with-param name="gruppenposition" select="2"/>
							<xsl:with-param name="elementposition" select="1"/>
							<xsl:with-param name="segmentknoten" select="."/>
						</xsl:call-template>				
					</xsl:when>						
				</xsl:choose>
			</xsl:for-each>
					
					
			<!-- PRI prüfen -->
			<xsl:variable name="counterPRI_SG33" select="count(G_ORDERS_SG33/S_PRI)"/>
		
			<xsl:if test="$counterPRI_SG33 &gt; 1">
				<xsl:call-template name="Fehler">
					<xsl:with-param name="segmentposition" select="$counterSegmente+$counterLIN+$counterPIA+$counterIMD+$counterQTY+$counterDTM_SG29+$counterMOA_SG29+$counterFTX_SG29+counterCCI_SG30+2"/>
					<xsl:with-param name="code" select="35"/>
				</xsl:call-template>
			</xsl:if>				
	
			<xsl:for-each select="G_ORDERS_SG33/S_PRI">
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C509/D_5125"/>
					<xsl:with-param name="max" select="3"/>
					<xsl:with-param name="wertebereich" select="'CAL'"/>		
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="elementposition" select="1"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C509/D_5118"/>
					<xsl:with-param name="max" select="15"/>
					<xsl:with-param name="zeichenart" select="'n'"/>
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="elementposition" select="2"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>
			</xsl:for-each>
									
					
					
			<!-- RFF prüfen -->
			<xsl:variable name="counterRFF_SG34" select="count(G_ORDERS_SG34/S_RFF)"/>
		
			<xsl:if test="$counterRFF_SG34 &gt; 5">
				<xsl:call-template name="Fehler">
					<xsl:with-param name="segmentposition" select="$counterSegmente+$counterLIN+$counterPIA+$counterIMD+$counterQTY+$counterDTM_SG29+$counterMOA_SG29+$counterFTX_SG29+counterCCI_SG30+counterPRI_SG33+6"/>
					<xsl:with-param name="code" select="35"/>
				</xsl:call-template>
			</xsl:if>				
	
			<xsl:for-each select="G_ORDERS_SG34/S_RFF">
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C506/D_1153"/>
					<xsl:with-param name="max" select="3"/>
					<xsl:with-param name="wertebereich" select="'AUU,Z09,Z03'"/>		
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="elementposition" select="1"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C506/D_1154"/>
					<xsl:with-param name="max" select="70"/>
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="elementposition" select="2"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>
			</xsl:for-each>
										
										
														
			<!-- LOC SG38 prüfen -->
			<xsl:variable name="counterLOC_SG38" select="count(G_ORDERS_SG38/S_LOC)"/>
			
			<xsl:choose>
				<xsl:when test="$counterLOC_SG38 &gt; 2">
					<xsl:call-template name="Fehler">
						<xsl:with-param name="segmentposition" select="$counterSegmente+$counterLIN+$counterPIA+$counterIMD+$counterQTY+$counterDTM_SG29+$counterMOA_SG29+$counterFTX_SG29+counterCCI_SG30+counterPRI_SG33+$counterRFF_SG34+3"/>
						<xsl:with-param name="code" select="35"/>
					</xsl:call-template>
				</xsl:when>
			</xsl:choose>				
			<xsl:for-each select="G_ORDERS_SG38/S_LOC">
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="D_3227"/>
					<xsl:with-param name="max" select="3"/>
					<xsl:with-param name="wertebereich" select="'172,237'"/>
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>	
				<xsl:call-template name="PruefeFeld">
					<xsl:with-param name="knoten" select="C_C517/D_3225"/>
					<xsl:with-param name="max" select="35"/>
					<xsl:with-param name="gruppenposition" select="2"/>
					<xsl:with-param name="elementposition" select="1"/>
					<xsl:with-param name="segmentknoten" select="."/>
				</xsl:call-template>
			</xsl:for-each>
	
		</xsl:template>

	<!-- Felderprüfungen -->
	<xsl:template name="PruefeFeld">
			
		<xsl:param name="knoten" required="yes"/>
		<xsl:param name="segment" required="no"/>
		<xsl:param name="zeichenart" required="no"/>		
		<xsl:param name="wertebereich" required="no"/>
		<xsl:param name="pflichtfeld" required="no" as="xs:boolean" select="true()"/>
		<xsl:param name="min" required="no"/>
		<xsl:param name="max" required="no"/>
		<xsl:param name="gruppenposition" required="yes"/>
		<xsl:param name="elementposition" required="no"/>
		<xsl:param name="segmentknoten" required="no"/>
				
		
					<xsl:message>prüfe feld - knoten:<xsl:value-of select="name($knoten)"/>-wert:<xsl:value-of select="$knoten"/> </xsl:message>

		<xsl:variable name="alpha" select="'abcdefghijklmnopqrstuvwxyzäöüABCDEFGHIJKLMNOPQRSTUVWXYZÄÖÜ'"/>

		<xsl:variable name="code" as="xs:string">
			<xsl:choose>
				<!-- 13 Fehlt -->
				<xsl:when test="(not($knoten) or $knoten='') and $pflichtfeld=true()">
					<xsl:value-of select="13"/>
				</xsl:when>
				<xsl:when test="$knoten">
					<xsl:choose>
						
						<!-- 12 Ungültiger Wert -->
						<xsl:when test="$wertebereich and not(exists(tokenize($wertebereich, ',')[. = $knoten]))">
							<xsl:value-of select="12"/>
						</xsl:when>				
						<!-- 38 Fehlende Ziffer vor dem Dezimalzeichen -->
						<xsl:when test="$zeichenart='n' and (substring($knoten, 1, 1) = '.' or substring($knoten, 1, 1) = ',' )">
							<xsl:value-of select="38"/>
						</xsl:when>		
						<!-- 37 Ungültige Zeichenart (numerisch)-->
						<xsl:when test="$zeichenart='n' and not($knoten castable as xs:double)">
							<xsl:value-of select="37"/>
						</xsl:when>		
						<!-- 39 Datenelement zu lang -->
						<xsl:when test="$max and string-length($knoten) &gt; number($max)">
							<xsl:value-of select="39"/>
						</xsl:when>		
						<!-- 40 Datenelement zu kurz -->
						<xsl:when test="$max and string-length($knoten) &lt; number($min)">
							<xsl:value-of select="40"/>
						</xsl:when>					
						<!-- Feld in Ordnung -->
						<xsl:otherwise>
							<xsl:value-of select="0"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>	
				<xsl:otherwise>
					<xsl:value-of select="0"/>
				</xsl:otherwise>				
			</xsl:choose>	
				
				
		</xsl:variable>
		
		
		<xsl:if test="$code != '0'">
		
	
			<xsl:choose>
				<xsl:when test="$segment='UNA' or $segment='UNB' or $segment='UNZ'">
					<xsl:call-template name="Fehler">
						<xsl:with-param name="code" select="$code"/>
						<xsl:with-param name="segment" select="$segment"/>
						<xsl:with-param name="gruppenposition" select="$gruppenposition"/>
						<xsl:with-param name="elementposition" select="$elementposition"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:when test="$segment='UNH' or $segment='UNT'">
					<xsl:call-template name="Fehler">
						<xsl:with-param name="referenzUNH" select="$knoten/ancestor::*[substring(name(), 1, 2)='M_']/S_UNH/D_0062"/>
						<xsl:with-param name="code" select="$code"/>
						<xsl:with-param name="segment" select="$segment"/>
						<xsl:with-param name="gruppenposition" select="$gruppenposition"/>
						<xsl:with-param name="elementposition" select="$elementposition"/>
					</xsl:call-template>
				</xsl:when>				
				<xsl:otherwise>
			
					<xsl:call-template name="Fehler">
						<xsl:with-param name="referenzUNH" select="$segmentknoten/ancestor::*[substring(name(), 1, 2)='M_']/S_UNH/D_0062"/>
						<xsl:with-param name="code" select="$code"/>
						<xsl:with-param name="segmentposition" select="count($segmentknoten/preceding::*[substring(name(), 1, 2)='S_' and name() != 'S_UNB' and name() != 'S_UNA']) + count($segmentknoten/ancestor::*[substring(name(), 1, 2)='S_' and name() != 'S_UNB' and name() != 'S_UNA'])+1"/>
						<xsl:with-param name="gruppenposition" select="$gruppenposition"/>
						<xsl:with-param name="elementposition" select="$elementposition"/>
					</xsl:call-template>			
				</xsl:otherwise>
			</xsl:choose>

		</xsl:if>
	</xsl:template>

		<!-- Fehler ausgeben -->
	<xsl:template name="Fehler">

		<xsl:param name="referenzUNH"/>		
		<xsl:param name="code"/>
		<xsl:param name="segment"/>
		<xsl:param name="segmentposition"/>
		<xsl:param name="gruppenposition"/>
		<xsl:param name="elementposition"/>
		
						<xsl:message>fehlertemplate</xsl:message>

		<xsl:variable name="fehlerart">
			<xsl:choose>
				<xsl:when test="$segment='UNA' or $segment='UNB' or $segment='UNZ'">
					<xsl:value-of select="'UCI'"/>
				</xsl:when>
				<xsl:when test="$segment='UNH' or $segment='UNT'">
					<xsl:value-of select="'UCM'"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:choose>
						<xsl:when test="$gruppenposition">
							<xsl:value-of select="'UCD'"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="'UCS'"/>
						</xsl:otherwise>										
					</xsl:choose>
				</xsl:otherwise>										
			</xsl:choose>
		</xsl:variable>
		
		
		
		<xsl:element name="{$fehlerart}">
			<referenzUNH><xsl:value-of select="$referenzUNH"/></referenzUNH>
			<code><xsl:value-of select="$code"/></code>
			<segment><xsl:value-of select="$segment"/></segment>
			<segmentposition><xsl:value-of select="$segmentposition"/></segmentposition>		
			<gruppenposition><xsl:value-of select="$gruppenposition"/></gruppenposition>
			<elementposition><xsl:value-of select="$elementposition"/></elementposition>
		</xsl:element>
		
		
	</xsl:template>
	
</xsl:stylesheet>
