<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:fn="http://www.w3.org/2005/xpath-functions" xmlns:rwe="http://www.rwe.com/gi/ada" exclude-result-prefixes="xs fn rwe">
	<xsl:output method="xml" version="1.0" encoding="ISO-8859-1" indent="yes"/>
	<xsl:variable name="now" select="current-dateTime()"/>
	<xsl:variable name="nachrichtennummer" select="concat('A', format-dateTime($now,
		'[Y02][M01][D01][H01][m01][s01]'), substring(format-dateTime($now, '[f01]'), 1, 1))"/>
	<!-- Default-Regel: alles unterdrücken -->
	<xsl:template match="* | @* | text()">
		<xsl:message terminate="yes">
			<xsl:text>Unberücksichtigt: </xsl:text>
			<xsl:for-each select="ancestor::node()">
				<xsl:value-of select="name()"/>
				<xsl:text>/</xsl:text>
			</xsl:for-each>
			<xsl:value-of select="name()"/>
		</xsl:message>
	</xsl:template>
	<xsl:template match="/">
		<xsl:copy>
			<xsl:apply-templates select="*" mode="copy"/>
		</xsl:copy>
	</xsl:template>
	<xsl:template match="/*" mode="copy">
		<xsl:copy>
			<xsl:call-template name="IDs"/>
			<xsl:apply-templates select="S_UNB" mode="copy"/>
			<xsl:apply-templates select="M_INSRPT/G_UTILMD_SG2/S_NAD[D_3035='MS']" mode="copy"/>
			<xsl:apply-templates select="M_INSRPT/G_UTILMD_SG2/S_NAD[D_3035='MR']" mode="copy"/>
			<AperakFehler>
				<xsl:choose>
					<xsl:when test="name() = 'EDIFACTINTERCHANGE'">
						<xsl:apply-templates select="."/>
					</xsl:when>
					<xsl:otherwise>
						<unb>
							<code>Z08</code>
							<freitext>Datei ist leer</freitext>
						</unb>
					</xsl:otherwise>
				</xsl:choose>
			</AperakFehler>
		</xsl:copy>
	</xsl:template>
	<xsl:template name="IDs">
		<IDs>
			<now>
				<xsl:value-of select="$now"/>
			</now>
			<nachrichtennummer>
				<xsl:value-of select="$nachrichtennummer"/>
			</nachrichtennummer>
			<nowFormatted>
				<xsl:value-of select="format-dateTime ($now, '[Y02][M01][D01]:[H01][m01]')"/>
			</nowFormatted>
			<nowDTM>
				<xsl:value-of select="format-dateTime($now, '[Y0002][M01][D01][H01][m01]')"/>
			</nowDTM>
		</IDs>
	</xsl:template>
	<xsl:template match="* | @* | text()" mode="copy">
		<xsl:copy>
			<xsl:apply-templates select="* | @* | text()" mode="copy"/>
		</xsl:copy>
	</xsl:template>
	<xsl:template match="EDIFACTINTERCHANGE">
		<xsl:choose>
			<xsl:when test="S_UNB">
				<xsl:apply-templates select="S_UNB"/>
				<!-- Nachrichten prüfen -->
				<xsl:apply-templates select="M_UTILMD"/>
			</xsl:when>
			<xsl:otherwise>
				<unb>
					<code>Z03</code>
					<freitext>Segment UNB fehlt</freitext>
				</unb>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- Felder im UNB-Segment prüfen -->
	<xsl:template match="S_UNB">
		<!-- C_S001/D_0001 muss existieren und 'UNOC' lauten -->
		<xsl:call-template name="unbValue">
			<xsl:with-param name="knoten" select="C_S001/D_0001"/>
			<xsl:with-param name="wert" select="'UNOC'"/>
			<xsl:with-param name="path" select="'UNB/S001/D0001'"/>
		</xsl:call-template>
		<!-- C_S001/D_0002 muss existieren und '3' lauten -->
		<xsl:call-template name="unbValue">
			<xsl:with-param name="knoten" select="C_S001/D_0002"/>
			<xsl:with-param name="wert" select="'3'"/>
			<xsl:with-param name="path" select="'UNB/S001/D0002'"/>
		</xsl:call-template>
		<!-- C_S002/D_0007 muss existieren und einen gültigen Eintrag aus einer Liste von Werten haben -->
		<xsl:call-template name="unbList">
			<xsl:with-param name="knoten" select="C_S002/D_0007"/>
			<xsl:with-param name="path" select="'UNB/S002/D0007'"/>
			<xsl:with-param name="list" select="'14,500,501,502,ZZZ'"/>
		</xsl:call-template>
		<!-- C_S003/D_0007 muss existieren und einen gültigen Eintrag aus einer Liste von Werten haben -->
		<xsl:call-template name="unbList">
			<xsl:with-param name="knoten" select="C_S003/D_0007"/>
			<xsl:with-param name="path" select="'UNB/S003/D0007'"/>
			<xsl:with-param name="list" select="'14,500,501,502,ZZZ'"/>
		</xsl:call-template>
		<!-- C_S004/D_0017 muss ein gültiges Datumsformat sein -->
		<xsl:call-template name="unbIsDate">
			<xsl:with-param name="knoten" select="C_S004/D_0017"/>
			<xsl:with-param name="path" select="'UNB/S004/D0017'"/>
		</xsl:call-template>
		<!-- C_S004/D_0019 muss ein gültiges Zeitformat sein -->
		<xsl:call-template name="unbIsTime">
			<xsl:with-param name="knoten" select="C_S004/D_0019"/>
			<xsl:with-param name="path" select="'UNB/S004/D0019'"/>
		</xsl:call-template>
		<!-- D_0026 muss, sofern vorhanden, aus einer Liste stammen -->
		<xsl:call-template name="unbList">
			<xsl:with-param name="knoten" select="D_0026"/>
			<xsl:with-param name="path" select="'UNB/D0026'"/>
			<xsl:with-param name="required" select="false()"/>
			<xsl:with-param name="list" select="'EM,VL,TL'"/>
		</xsl:call-template>
		<!-- D_0032 muss, sofern vorhanden, DISI lauten -->
		<xsl:call-template name="unbValue">
			<xsl:with-param name="knoten" select="D_0032"/>
			<xsl:with-param name="path" select="'UNB/D0032'"/>
			<xsl:with-param name="required" select="false()"/>
			<xsl:with-param name="wert" select="'DISI'"/>
		</xsl:call-template>
	</xsl:template>
	<!-- **************************************************************************************  -->
	<!-- **************************************************************************************  -->
	<!-- *****                                                                            *****  -->
	<!-- *****                     Nachrichten (UNHs) prüfen                              *****  -->
	<!-- *****                                                                            *****  -->
	<!-- **************************************************************************************  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="M_UTILMD">
		<xsl:variable name="nachrichtID" select="S_UNH/D_0062"/>
		<xsl:apply-templates select="descendant::node()[substring(name(), 1, 2) = 'S_']">
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:apply-templates>
		<xsl:apply-templates select="." mode="Absender">
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:apply-templates>
		<xsl:apply-templates select="." mode="Empfaenger">
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:apply-templates>
	</xsl:template>
	<xsl:template match="M_UTILMD" mode="Absender">
		<xsl:param name="nachrichtID"/>
		<xsl:choose>
			<xsl:when test="G_UTILMD_SG2/S_NAD[D_3035='MS']">
				<xsl:apply-templates select="G_UTILMD_SG2/S_NAD[D_3035='MS']" mode="Absender">
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:apply-templates>
			</xsl:when>
			<xsl:otherwise>
				<unh>
					<code>Z08</code>
					<freitext>Segment SG2/NAD fuer Absender fehlt</freitext>
					<referenz>
						<xsl:value-of select="$nachrichtID"/>
					</referenz>
					<segment>0</segment>
				</unh>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="G_UTILMD_SG2/S_NAD[D_3035='MS']" mode="Absender">
		<xsl:param name="nachrichtID"/>
		<xsl:choose>
			<xsl:when test="C_C082/D_3039">
				<xsl:if test="C_C082/D_3039 = ''">
					<unh>
						<code>Z03</code>
						<freitext>Feld SG2/NAD/C082/3039 fuer Qualifier MS leer</freitext>
						<referenz>
							<xsl:value-of select="$nachrichtID"/>
						</referenz>
						<segment>0</segment>
					</unh>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<unh>
					<code>Z03</code>
					<freitext>Feld SG2/NAD/C082/3039 fuer Qualifier MS fehlt</freitext>
					<referenz>
						<xsl:value-of select="$nachrichtID"/>
					</referenz>
					<segment>0</segment>
				</unh>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="M_UTILMD" mode="Empfaenger">
		<xsl:param name="nachrichtID"/>
		<xsl:choose>
			<xsl:when test="G_UTILMD_SG2/S_NAD[D_3035='MR']">
				<xsl:apply-templates select="G_UTILMD_SG2/S_NAD[D_3035='MR']" mode="Empfaenger">
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:apply-templates>
			</xsl:when>
			<xsl:otherwise>
				<unh>
					<code>Z08</code>
					<freitext>Segment SG2/NAD fuer Absender fehlt</freitext>
					<referenz>
						<xsl:value-of select="$nachrichtID"/>
					</referenz>
					<segment>0</segment>
				</unh>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="G_UTILMD_SG2/S_NAD[D_3035='MR']" mode="Empfaenger">
		<xsl:param name="nachrichtID"/>
		<xsl:choose>
			<xsl:when test="C_C082/D_3039">
				<xsl:if test="C_C082/D_3039 = ''">
					<unh>
						<code>Z03</code>
						<freitext>Feld SG2/NAD/C082/3039 fuer Qualifier MR leer</freitext>
						<referenz>
							<xsl:value-of select="$nachrichtID"/>
						</referenz>
						<segment>0</segment>
					</unh>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<unh>
					<code>Z03</code>
					<freitext>Feld SG2/NAD/C082/3039 fuer Qualifier MR fehlt</freitext>
					<referenz>
						<xsl:value-of select="$nachrichtID"/>
					</referenz>
					<segment>0</segment>
				</unh>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- **************************************************************************************  -->
	<!-- *****            S_UNH prüfen                                                    *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="S_UNH">
		<xsl:param name="nachrichtID"/>
		<xsl:variable name="segment" select="position()"/>
		<xsl:apply-templates select="C_S009">
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:apply-templates>
		<xsl:apply-templates select="C_S010">
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:apply-templates>
	</xsl:template>
	<xsl:template match="S_UNH/C_S009">
		<xsl:param name="segment"/>
		<xsl:param name="nachrichtID"/>
		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="D_0065"/>
			<xsl:with-param name="wert" select="'UTILMD'"/>
			<xsl:with-param name="path" select="'UNH/S009/D0065'"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="segment" select="$segment"/>
		</xsl:call-template>
		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="D_0052"/>
			<xsl:with-param name="wert" select="'D'"/>
			<xsl:with-param name="path" select="'UNH/S009/D0052'"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="segment" select="$segment"/>
		</xsl:call-template>
		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="D_0054"/>
			<xsl:with-param name="wert" select="'11A'"/>
			<xsl:with-param name="path" select="'UNH/S009/D0054'"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="segment" select="$segment"/>
		</xsl:call-template>
		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="D_0051"/>
			<xsl:with-param name="wert" select="'UN'"/>
			<xsl:with-param name="path" select="'UNH/S009/D0051'"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="segment" select="$segment"/>
		</xsl:call-template>
		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="D_0057"/>
			<!-- Ab dem 01.10.2011: -->
			<xsl:with-param name="wert" select="'5.1a'"/>
			<xsl:with-param name="path" select="'UNH/S009/D0057'"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="segment" select="$segment"/>
		</xsl:call-template>
	</xsl:template>
	<xsl:template match="S_UNH/C_S010">
		<xsl:param name="segment"/>
		<xsl:param name="nachrichtID"/>
		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="D_0070"/>
			<xsl:with-param name="path" select="'UNH/S010/D0070'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="D_0073"/>
			<xsl:with-param name="path" select="'UNH/S010/D0073'"/>
			<xsl:with-param name="list" select="'C,F'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="required" select="false()"/>
		</xsl:call-template>
	</xsl:template>
	<!-- **************************************************************************************  -->
	<!-- *****            S_BGM prüfen                                                    *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="S_BGM">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="C_C002/D_1001"/>
			<xsl:with-param name="path" select="'BGM/C0002/1001'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="list" select="'E01,E02,E03,E06,Z14,E35,E44,Z01,Z02,E40,Z05,Z07,Z08,Z13,Z17,Z18'"/>
		</xsl:call-template>
		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_C106/D_1004"/>
			<xsl:with-param name="path" select="'BGM/C106/1004'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
	</xsl:template>
	<!-- **************************************************************************************  -->
	<!-- *****            S_DTM unter UTILMD-Wurzel prüfen                                *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="M_UTILMD/S_DTM">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="C_C507/D_2005"/>
			<xsl:with-param name="path" select="'DTM/C507/2005'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="list" select="'137,157,735'"/>
		</xsl:call-template>
		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_C507/D_2380"/>
			<xsl:with-param name="path" select="'DTM/C507/2380'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="C_C507/D_2379"/>
			<xsl:with-param name="path" select="'DTM/C507/2379'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="list" select="'203,406,610'"/>
		</xsl:call-template>
		<xsl:choose>
			<xsl:when test="(not(C_C507/D_2005) and not (C_C507/D_2379)) 
			or ((C_C507/D_2005='137' and C_C507/D_2379='203') 
			or (C_C507/D_2005='735' and C_C507/D_2379='406') 
			or (C_C507/D_2005='157' and C_C507/D_2379='610'))"/>
			<xsl:otherwise>
				<unh>
					<code>Z01</code>
					<freitext>Feld DTM/C507/2379: falscher Datumsformat-Qualifier fuer den Datumstyp</freitext>
					<segment>
						<xsl:value-of select="$segment"/>
					</segment>
					<referenz>
						<xsl:value-of select="$nachrichtID"/>
					</referenz>
				</unh>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:apply-templates select="C_C507" mode="validateFormat">
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:apply-templates>
	</xsl:template>
	<!-- **************************************************************************************  -->
	<!-- *****            S_DTM in Segmentgruppe 4 prüfen                                 *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_UTILMD_SG4/S_DTM">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="C_C507/D_2005"/>
			<xsl:with-param name="path" select="'DTM/C507/2005'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="list" select="'76,294,92,93,157,471,155,752,672,158,159,Z01,Z05,Z06,Z07,Z08,Z09,Z10'"/>
		</xsl:call-template>
		
		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_C507/D_2380"/>
			<xsl:with-param name="path" select="'DTM/C507/2380'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="C_C507/D_2379"/>
			<xsl:with-param name="path" select="'DTM/C507/2379'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="list" select="'102,104,106,203,802,Z01,602'"/>
		</xsl:call-template>
		
		<xsl:apply-templates select="C_C507" mode="qualifiersValid">
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:apply-templates>
		
		<xsl:apply-templates select="C_C507" mode="validateFormat">
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:apply-templates>
	</xsl:template>
	<xsl:template match="G_UTILMD_SG4/S_DTM/C_C507[D_2005='76']" mode="qualifiersValid" priority="10">
		<xsl:param name="segment"/>
		<xsl:param name="nachrichtID"/>
		<xsl:if test="D_2379 != '102'">
			<unh>
				<code>Z01</code>
				<freitext>
					<xsl:text>Feld SGDTM/C507/2379: falscher Datumsformat-Qualifier </xsl:text>
					<xsl:value-of select="D_2379"/>
					<xsl:text>fuer den Datumstyp 76</xsl:text>
				</freitext>
				<segment>
					<xsl:value-of select="$segment"/>
				</segment>
				<referenz>
					<xsl:value-of select="$nachrichtID"/>
				</referenz>
			</unh>
		</xsl:if>
	</xsl:template>
	<xsl:template match="G_UTILMD_SG4/S_DTM/C_C507[D_2005='294']" mode="qualifiersValid" priority="10">
		<xsl:param name="segment"/>
		<xsl:param name="nachrichtID"/>
		<xsl:if test="D_2379 != '203'">
			<unh>
				<code>Z01</code>
				<freitext>
					<xsl:text>Feld SGDTM/C507/2379: falscher Datumsformat-Qualifier </xsl:text>
					<xsl:value-of select="D_2379"/>
					<xsl:text>fuer den Datumstyp 294</xsl:text>
				</freitext>
				<segment>
					<xsl:value-of select="$segment"/>
				</segment>
				<referenz>
					<xsl:value-of select="$nachrichtID"/>
				</referenz>
			</unh>
		</xsl:if>
	</xsl:template>
	<xsl:template match="G_UTILMD_SG4/S_DTM/C_C507[D_2005='92']" mode="qualifiersValid" priority="10">
		<xsl:param name="segment"/>
		<xsl:param name="nachrichtID"/>
		<xsl:if test="D_2379 != '102'">
			<unh>
				<code>Z01</code>
				<freitext>
					<xsl:text>Feld SGDTM/C507/2379: falscher Datumsformat-Qualifier </xsl:text>
					<xsl:value-of select="D_2379"/>
					<xsl:text>fuer den Datumstyp 92</xsl:text>
				</freitext>
				<segment>
					<xsl:value-of select="$segment"/>
				</segment>
				<referenz>
					<xsl:value-of select="$nachrichtID"/>
				</referenz>
			</unh>
		</xsl:if>
	</xsl:template>
	<xsl:template match="G_UTILMD_SG4/S_DTM/C_C507[D_2005='93']" mode="qualifiersValid" priority="10">
		<xsl:param name="segment"/>
		<xsl:param name="nachrichtID"/>
		<xsl:if test="D_2379 != '102'">
			<unh>
				<code>Z01</code>
				<freitext>
					<xsl:text>Feld SGDTM/C507/2379: falscher Datumsformat-Qualifier </xsl:text>
					<xsl:value-of select="D_2379"/>
					<xsl:text>fuer den Datumstyp 93</xsl:text>
				</freitext>
				<segment>
					<xsl:value-of select="$segment"/>
				</segment>
				<referenz>
					<xsl:value-of select="$nachrichtID"/>
				</referenz>
			</unh>
		</xsl:if>
	</xsl:template>
	<xsl:template match="G_UTILMD_SG4/S_DTM/C_C507[D_2005='157']" mode="qualifiersValid" priority="10">
		<xsl:param name="segment"/>
		<xsl:param name="nachrichtID"/>
		<xsl:if test="D_2379 != '102' and D_2379 != '203'">
			<unh>
				<code>Z01</code>
				<freitext>
					<xsl:text>Feld SGDTM/C507/2379: falscher Datumsformat-Qualifier </xsl:text>
					<xsl:value-of select="D_2379"/>
					<xsl:text>fuer den Datumstyp 157</xsl:text>
				</freitext>
				<segment>
					<xsl:value-of select="$segment"/>
				</segment>
				<referenz>
					<xsl:value-of select="$nachrichtID"/>
				</referenz>
			</unh>
		</xsl:if>
	</xsl:template>
	<xsl:template match="G_UTILMD_SG4/S_DTM/C_C507[D_2005='471']" mode="qualifiersValid" priority="10">
		<xsl:param name="segment"/>
		<xsl:param name="nachrichtID"/>
		<xsl:if test="D_2379 != '102'">
			<unh>
				<code>Z01</code>
				<freitext>
					<xsl:text>Feld SGDTM/C507/2379: falscher Datumsformat-Qualifier </xsl:text>
					<xsl:value-of select="D_2379"/>
					<xsl:text>fuer den Datumstyp 471</xsl:text>
				</freitext>
				<segment>
					<xsl:value-of select="$segment"/>
				</segment>
				<referenz>
					<xsl:value-of select="$nachrichtID"/>
				</referenz>
			</unh>
		</xsl:if>
	</xsl:template>
	<xsl:template match="G_UTILMD_SG4/S_DTM/C_C507[D_2005='155']" mode="qualifiersValid" priority="10">
		<xsl:param name="segment"/>
		<xsl:param name="nachrichtID"/>
		<xsl:if test="D_2379 != '102'">
			<unh>
				<code>Z01</code>
				<freitext>
					<xsl:text>Feld SGDTM/C507/2379: falscher Datumsformat-Qualifier </xsl:text>
					<xsl:value-of select="D_2379"/>
					<xsl:text>fuer den Datumstyp 155</xsl:text>
				</freitext>
				<segment>
					<xsl:value-of select="$segment"/>
				</segment>
				<referenz>
					<xsl:value-of select="$nachrichtID"/>
				</referenz>
			</unh>
		</xsl:if>
	</xsl:template>
	<xsl:template match="G_UTILMD_SG4/S_DTM/C_C507[D_2005='752']" mode="qualifiersValid" priority="10">
		<xsl:param name="segment"/>
		<xsl:param name="nachrichtID"/>
		<xsl:if test="D_2379 != '104' and D_2379 != '106'">
			<unh>
				<code>Z01</code>
				<freitext>
					<xsl:text>Feld SGDTM/C507/2379: falscher Datumsformat-Qualifier </xsl:text>
					<xsl:value-of select="D_2379"/>
					<xsl:text>fuer den Datumstyp 752</xsl:text>
				</freitext>
				<segment>
					<xsl:value-of select="$segment"/>
				</segment>
				<referenz>
					<xsl:value-of select="$nachrichtID"/>
				</referenz>
			</unh>
		</xsl:if>
	</xsl:template>
	<xsl:template match="G_UTILMD_SG4/S_DTM/C_C507[D_2005='672']" mode="qualifiersValid" priority="10">
		<xsl:param name="segment"/>
		<xsl:param name="nachrichtID"/>
		<xsl:if test="D_2379 != '802'">
			<unh>
				<code>Z01</code>
				<freitext>
					<xsl:text>Feld SGDTM/C507/2379: falscher Datumsformat-Qualifier </xsl:text>
					<xsl:value-of select="D_2379"/>
					<xsl:text>fuer den Datumstyp 672</xsl:text>
				</freitext>
				<segment>
					<xsl:value-of select="$segment"/>
				</segment>
				<referenz>
					<xsl:value-of select="$nachrichtID"/>
				</referenz>
			</unh>
		</xsl:if>
	</xsl:template>
	<xsl:template match="G_UTILMD_SG4/S_DTM/C_C507[D_2005='158']" mode="qualifiersValid" priority="10">
		<xsl:param name="segment"/>
		<xsl:param name="nachrichtID"/>
		<xsl:if test="D_2379 != '102' and D_2379 != '203'">
			<unh>
				<code>Z01</code>
				<freitext>
					<xsl:text>Feld SGDTM/C507/2379: falscher Datumsformat-Qualifier </xsl:text>
					<xsl:value-of select="D_2379"/>
					<xsl:text>fuer den Datumstyp 158</xsl:text>
				</freitext>
				<segment>
					<xsl:value-of select="$segment"/>
				</segment>
				<referenz>
					<xsl:value-of select="$nachrichtID"/>
				</referenz>
			</unh>
		</xsl:if>
	</xsl:template>
	<xsl:template match="G_UTILMD_SG4/S_DTM/C_C507[D_2005='159']" mode="qualifiersValid" priority="10">
		<xsl:param name="segment"/>
		<xsl:param name="nachrichtID"/>
		<xsl:if test="D_2379 != '102' and D_2379 != '203'">
			<unh>
				<code>Z01</code>
				<freitext>
					<xsl:text>Feld SGDTM/C507/2379: falscher Datumsformat-Qualifier </xsl:text>
					<xsl:value-of select="D_2379"/>
					<xsl:text>fuer den Datumstyp 159</xsl:text>
				</freitext>
				<segment>
					<xsl:value-of select="$segment"/>
				</segment>
				<referenz>
					<xsl:value-of select="$nachrichtID"/>
				</referenz>
			</unh>
		</xsl:if>
	</xsl:template>
	<xsl:template match="G_UTILMD_SG4/S_DTM/C_C507[D_2005='Z01']" mode="qualifiersValid" priority="10">
		<xsl:param name="segment"/>
		<xsl:param name="nachrichtID"/>
		<xsl:if test="D_2379 != 'Z01' and D_2379 != '102' and D_2379 != '106'">
			<unh>
				<code>Z01</code>
				<freitext>
					<xsl:text>Feld SGDTM/C507/2379: falscher Datumsformat-Qualifier </xsl:text>
					<xsl:value-of select="D_2379"/>
					<xsl:text>fuer den Datumstyp Z01</xsl:text>
				</freitext>
				<segment>
					<xsl:value-of select="$segment"/>
				</segment>
				<referenz>
					<xsl:value-of select="$nachrichtID"/>
				</referenz>
			</unh>
		</xsl:if>
	</xsl:template>
	<xsl:template match="G_UTILMD_SG4/S_DTM/C_C507[D_2005='Z05']" mode="qualifiersValid" priority="10">
		<xsl:param name="segment"/>
		<xsl:param name="nachrichtID"/>
		<xsl:if test="D_2379 != '102'">
			<unh>
				<code>Z01</code>
				<freitext>
					<xsl:text>Feld SGDTM/C507/2379: falscher Datumsformat-Qualifier </xsl:text>
					<xsl:value-of select="D_2379"/>
					<xsl:text>fuer den Datumstyp Z05</xsl:text>
				</freitext>
				<segment>
					<xsl:value-of select="$segment"/>
				</segment>
				<referenz>
					<xsl:value-of select="$nachrichtID"/>
				</referenz>
			</unh>
		</xsl:if>
	</xsl:template>
	<xsl:template match="G_UTILMD_SG4/S_DTM/C_C507[D_2005='Z06']" mode="qualifiersValid" priority="10">
		<xsl:param name="segment"/>
		<xsl:param name="nachrichtID"/>
		<xsl:if test="D_2379 != '102'">
			<unh>
				<code>Z01</code>
				<freitext>
					<xsl:text>Feld SGDTM/C507/2379: falscher Datumsformat-Qualifier </xsl:text>
					<xsl:value-of select="D_2379"/>
					<xsl:text>fuer den Datumstyp Z06</xsl:text>
				</freitext>
				<segment>
					<xsl:value-of select="$segment"/>
				</segment>
				<referenz>
					<xsl:value-of select="$nachrichtID"/>
				</referenz>
			</unh>
		</xsl:if>
	</xsl:template>
	<xsl:template match="G_UTILMD_SG4/S_DTM/C_C507[D_2005='Z07']" mode="qualifiersValid" priority="10">
		<xsl:param name="segment"/>
		<xsl:param name="nachrichtID"/>
		<xsl:if test="D_2379 != '102'">
			<unh>
				<code>Z01</code>
				<freitext>
					<xsl:text>Feld SGDTM/C507/2379: falscher Datumsformat-Qualifier </xsl:text>
					<xsl:value-of select="D_2379"/>
					<xsl:text>fuer den Datumstyp Z07</xsl:text>
				</freitext>
				<segment>
					<xsl:value-of select="$segment"/>
				</segment>
				<referenz>
					<xsl:value-of select="$nachrichtID"/>
				</referenz>
			</unh>
		</xsl:if>
	</xsl:template>
	<xsl:template match="G_UTILMD_SG4/S_DTM/C_C507[D_2005='Z08']" mode="qualifiersValid" priority="10">
		<xsl:param name="segment"/>
		<xsl:param name="nachrichtID"/>
		<xsl:if test="D_2379 != '102'">
			<unh>
				<code>Z01</code>
				<freitext>
					<xsl:text>Feld SGDTM/C507/2379: falscher Datumsformat-Qualifier </xsl:text>
					<xsl:value-of select="D_2379"/>
					<xsl:text>fuer den Datumstyp Z08</xsl:text>
				</freitext>
				<segment>
					<xsl:value-of select="$segment"/>
				</segment>
				<referenz>
					<xsl:value-of select="$nachrichtID"/>
				</referenz>
			</unh>
		</xsl:if>
	</xsl:template>
	<xsl:template match="G_UTILMD_SG4/S_DTM/C_C507[D_2005='Z09']" mode="qualifiersValid" priority="10">
		<xsl:param name="segment"/>
		<xsl:param name="nachrichtID"/>
		<xsl:if test="D_2379 != '602'">
			<unh>
				<code>Z01</code>
				<freitext>
					<xsl:text>Feld SGDTM/C507/2379: falscher Datumsformat-Qualifier </xsl:text>
					<xsl:value-of select="D_2379"/>
					<xsl:text>fuer den Datumstyp Z09</xsl:text>
				</freitext>
				<segment>
					<xsl:value-of select="$segment"/>
				</segment>
				<referenz>
					<xsl:value-of select="$nachrichtID"/>
				</referenz>
			</unh>
		</xsl:if>
	</xsl:template>
	<xsl:template match="G_UTILMD_SG4/S_DTM/C_C507[D_2005='Z10']" mode="qualifiersValid" priority="10">
		<xsl:param name="segment"/>
		<xsl:param name="nachrichtID"/>
		<xsl:if test="D_2379 != 'Z01'">
			<unh>
				<code>Z01</code>
				<freitext>
					<xsl:text>Feld SGDTM/C507/2379: falscher Datumsformat-Qualifier </xsl:text>
					<xsl:value-of select="D_2379"/>
					<xsl:text>fuer den Datumstyp Z10</xsl:text>
				</freitext>
				<segment>
					<xsl:value-of select="$segment"/>
				</segment>
				<referenz>
					<xsl:value-of select="$nachrichtID"/>
				</referenz>
			</unh>
		</xsl:if>
	</xsl:template>
	<xsl:template match="G_UTILMD_SG4/S_DTM/C_C507" mode="qualifiersValid" priority="5">
		<xsl:param name="segment"/>
		<xsl:param name="nachrichtID"/>
		<unh>
			<code>Z01</code>
			<freitext>Unbekannter Wert fuer SG4/DTM/C507/2005: <xsl:value-of select="D_2005"/>
			</freitext>
			<segment>
				<xsl:value-of select="$segment"/>
			</segment>
			<referenz>
				<xsl:value-of select="$nachrichtID"/>
			</referenz>
		</unh>
	</xsl:template>
	<!-- **************************************************************************************  -->
	<!-- *****            S_RFF prüfen                                                    *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="M_UTILMD/G_UTILMD_SG1/S_RFF">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		<xsl:apply-templates select="C_C506">
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:apply-templates>
	</xsl:template>
	<xsl:template match="S_RFF/C_C506">
		<xsl:param name="segment" as="xs:integer"/>
		<xsl:param name="nachrichtID"/>
		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="D_1153"/>
			<xsl:with-param name="wert" select="'AAV'"/>
			<xsl:with-param name="path" select="'SG1/RFF/C506/1153'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="D_1154"/>
			<xsl:with-param name="path" select="'SG1/RFF/C506/1154'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
	</xsl:template>
	<!-- **************************************************************************************  -->
	<!-- *****            S_NAD der 2. Segmentgruppe prüfen                               *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="M_UTILMD/G_UTILMD_SG2/S_NAD">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="D_3035"/>
			<xsl:with-param name="path" select="'SG2/NAD/3035'"/>
			<xsl:with-param name="list" select="'MS,MR'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="C_C082/D_3055_1"/>
			<xsl:with-param name="path" select="'SG2/NAD/C082/3055'"/>
			<xsl:with-param name="list" select="'9,293,305,321,332'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
	</xsl:template>
	<!-- **************************************************************************************  -->
	<!-- *****            S_CTA der 3. Segmentgruppe prüfen                               *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="M_UTILMD/G_UTILMD_SG2/G_UTILMD_SG3/S_CTA">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="D_3139"/>
			<xsl:with-param name="wert" select="'IC'"/>
			<xsl:with-param name="path" select="'SG2/SG3/CTA/3139'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_C056/D_3412"/>
			<xsl:with-param name="path" select="'SG2/SG3/CTA/C056/3412'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
	</xsl:template>
	<!-- **************************************************************************************  -->
	<!-- *****            S_COM der 3. Segmentgruppe prüfen                               *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="M_UTILMD/G_UTILMD_SG2/G_UTILMD_SG3/S_COM">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_C076/D_3148"/>
			<xsl:with-param name="path" select="'SG2/SG3/COM/C076/3148'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="C_C076/D_3155"/>
			<xsl:with-param name="path" select="'SG2/SG3/COM/3155'"/>
			<xsl:with-param name="list" select="'EM,FX,TE,AJ,AL'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
	</xsl:template>
	<!-- **************************************************************************************  -->
	<!-- *****            S_IMD  prüfen                            								    *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_UTILMD_SG4/S_IMD">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="C_C272/D_7081"/>
			<xsl:with-param name="path" select="'SG4/IMD/C272/7081'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="list" select="'Z04,Z05,Z14'"/>
		</xsl:call-template>
		<xsl:choose>
			<xsl:when test="C_C272/D_7081='Z04'">
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="C_C273/D_7009"/>
					<xsl:with-param name="path" select="'SG4/IMD/C273/7009'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					<xsl:with-param name="list" select="'Z01,Z02,Z03'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="C_C272/D_7081='Z05'">
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="C_C273/D_7009"/>
					<xsl:with-param name="path" select="'SG4/IMD/C273/7009'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					<xsl:with-param name="list" select="'Z04,Z05'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="C_C272/D_7081='Z14'">
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="C_C273/D_7009"/>
					<xsl:with-param name="path" select="'SG4/IMD/C273/7009'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					<xsl:with-param name="list" select="'Z06,Z07'"/>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- **************************************************************************************  -->
	<!-- *****            S_STS  prüfen                            								    *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_UTILMD_SG4/S_STS">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="C_C601/D_9015"/>
			<xsl:with-param name="path" select="'SG4/STS/C601/9015'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="list" select="'7,E01,Z17,Z04'"/>
		</xsl:call-template>
		<xsl:choose>
			<xsl:when test="C_C601/D_9015='7'">
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="C_C556_1/D_9013"/>
					<xsl:with-param name="path" select="'SG4/STS/C556/9013'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					<xsl:with-param name="list" select="'E01,E02,E03,E04,E05,E06,Z26,Z33,Z36,Z37,Z38,Z39,Z40,Z41,Z46,Z47,Z69,ZB1,ZB2,ZB3,ZC6,ZC7,ZC8,ZC9,ZD0,ZD2,ZD9'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="C_C601/D_9015='E01'">
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="C_C556_1/D_9013"/>
					<xsl:with-param name="path" select="'SG4/STS/C556/9013'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					<xsl:with-param name="list" select="'E11,E12,E13,E14,E15,E17,Z01,Z07,Z08,Z09,Z11,Z12,Z13,Z14,Z15,Z29,Z30,Z34,Z35,Z43,Z44,Z45,Z48,Z49,Z50,Z56,E62,Z54,Z57,Z58,Z59,Z60,Z61,Z62,ZB6,ZB7,ZB4,ZB5,ZC5,ZD3,ZD4,ZD5,ZD6'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="C_C601/D_9015='Z17'">
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="C_C556_1/D_9013"/>
					<xsl:with-param name="path" select="'SG4/STS/C556/9013'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					<xsl:with-param name="list" select="'E01,E03,E04'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="C_C601/D_9015='Z04'">
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="C_C556_1/D_9013"/>
					<xsl:with-param name="path" select="'SG4/STS/C556/9013'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					<xsl:with-param name="list" select="'Z01,Z03,Z04,Z06'"/>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- **************************************************************************************  -->
	<!-- *****            S_FTX  prüfen                            								    *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_UTILMD_SG4/S_FTX">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="D_4451"/>
			<xsl:with-param name="path" select="'SG4/FTX/4451'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="list" select="'AAI,ACB,ABO,ADM,Z01'"/>
		</xsl:call-template>
		<xsl:if test="D_4451='ABO'">
			<xsl:call-template name="unhList">
				<xsl:with-param name="knoten" select="C_C107/D_4441"/>
				<xsl:with-param name="path" select="'SG4/FTX/C107/4441'"/>
				<xsl:with-param name="segment" select="$segment"/>
				<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				<xsl:with-param name="list" select="'Z03,Z04,Z05,Z06'"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="D_4451='ADM'">
			<xsl:call-template name="unhValue">
				<xsl:with-param name="knoten" select="C_C107/D_4441"/>
				<xsl:with-param name="path" select="'SG4/FTX/C107/4441'"/>
				<xsl:with-param name="segment" select="$segment"/>
				<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				<xsl:with-param name="wert" select="'Z01'"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	<!-- **************************************************************************************  -->
	<!-- *****            S_AGR prüfen                            								    *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_UTILMD_SG4/S_AGR">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="C_C543/D_7431"/>
			<xsl:with-param name="path" select="'SG4/AGR/C543/7431'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="list" select="'11,E03,Z01,9'"/>
		</xsl:call-template>
		<xsl:choose>
			<xsl:when test="C_C543/D_7431='11'">
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="C_C543/D_7433"/>
					<xsl:with-param name="path" select="'SG4/FTX/C107/4441'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					<xsl:with-param name="list" select="'E01,E02'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="C_C543/D_7431='E03'">
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="C_C543/D_7433"/>
					<xsl:with-param name="path" select="'SG4/FTX/C107/4441'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					<xsl:with-param name="list" select="'E09,E10'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="C_C543/D_7431='Z01'">
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="C_C543/D_7433"/>
					<xsl:with-param name="path" select="'SG4/FTX/C107/4441'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					<xsl:with-param name="list" select="'E09,E10'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="C_C543/D_7431='9'">
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="C_C543/D_7433"/>
					<xsl:with-param name="path" select="'SG4/FTX/C107/4441'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					<xsl:with-param name="list" select="'Z04,Z05,Z06'"/>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- **************************************************************************************  -->
	<!-- *****            S_IDE prüfen                                                    *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="S_IDE">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="D_7495"/>
			<xsl:with-param name="wert" select="'24'"/>
			<xsl:with-param name="path" select="'SG4/IDE/7495'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_C206/D_7402"/>
			<xsl:with-param name="path" select="'SG4/IDE/C206/7402'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
	</xsl:template>
	<!-- **************************************************************************************  -->
	<!-- *****            S_LOC prüfen                                                    *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="S_LOC">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="D_3227"/>
			<xsl:with-param name="path" select="'SG4/SG5/LOC/3227'"/>
			<xsl:with-param name="list" select="'Z02,Z03,Z05,107,237,231,172'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		<!--<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_C517/D_3225"/>
			<xsl:with-param name="path" select="'SG4/SG5/LOC/C517/3225'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>-->
		<xsl:variable name="kategorie" select="../../../../M_UTILMD/S_BGM/C_C002/D_1001"/>
		<xsl:choose>
			<xsl:when test="D_3227='Z02' or D_3227='Z03' or D_3227='Z05'">
				<xsl:choose>
					<xsl:when test="not(C_C517/D_3055_1) or (C_C517/D_3055_1='89' or C_C517/D_3055_1='293')"/>
					<xsl:otherwise>
						<unh>
							<code>Z01</code>
							<freitext>Feld SG4/SG5/LOC/C517/3055 mit Ortsangabe-Qualifier Z02, Z03 oder Z05 muss 89 oder 293 lauten</freitext>
							<segment>
								<xsl:value-of select="$segment"/>
							</segment>
							<referenz>
								<xsl:value-of select="$nachrichtID"/>
							</referenz>
						</unh>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:if test="$kategorie='Z05'">
					<xsl:choose>
						<xsl:when test="not(C_C517/D_3225='')"/>
						<xsl:otherwise>
							<unh>
								<code>Z03</code>
								<freitext>Klimazone / Temperaturmessstelle / Referenzmessung fuer das Feld SG4/SG5/S_LOC/C_C517/D_3225 mit Ortsangabe-Qualifier Z02 oder Z03 fehlt</freitext>
								<segment>
									<xsl:value-of select="$segment"/>
								</segment>
								<referenz>
									<xsl:value-of select="$nachrichtID"/>
								</referenz>
							</unh>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:if>
			</xsl:when>
			<xsl:when test="D_3227='107'">
				<xsl:if test="($kategorie='Z07' and ../../S_DTM/C_C507[D_2005='158']) or $kategorie='Z05' or $kategorie='E40'">
					<xsl:call-template name="unhRequired">
						<xsl:with-param name="knoten" select="C_C517/D_3225"/>
						<xsl:with-param name="path" select="'SG4/SG5/S_LOC/C_C517/D_3225'"/>
						<xsl:with-param name="segment" select="$segment"/>
						<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<xsl:when test="D_3227='237'">
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="D_5479"/>
					<xsl:with-param name="list" select="'1,2,3,4,5,6'"/>
					<xsl:with-param name="path" select="'SSG4/SG5/S_LOC/5479'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					<xsl:with-param name="required" select="false()"/>
				</xsl:call-template>
				<xsl:if test="(../../S_DTM/C_C507[D_2005='158'] and $kategorie='Z07') or $kategorie='E40' ">
					<xsl:call-template name="unhRequired">
						<xsl:with-param name="knoten" select="C_C517/D_3225"/>
						<xsl:with-param name="path" select="'SG4/SG5/S_LOC/C_C517/D_3225'"/>
						<xsl:with-param name="segment" select="$segment"/>
						<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<xsl:when test="D_3227='231'">
				<xsl:call-template name="unhValue">
					<xsl:with-param name="knoten" select="C_C517/D_3055_1"/>
					<xsl:with-param name="wert" select="'305'"/>
					<xsl:with-param name="path" select="'SG4/SG5/LOC/C517/3055'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:call-template>
				<xsl:if test="(../../S_DTM/C_C507[D_2005='158']) and $kategorie='Z07'">
					<xsl:call-template name="unhRequired">
						<xsl:with-param name="knoten" select="C_C517/D_3225"/>
						<xsl:with-param name="path" select="'SG4/SG5/S_LOC/C_C517/D_3225'"/>
						<xsl:with-param name="segment" select="$segment"/>
						<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<xsl:when test="D_3227='172'">
				<xsl:call-template name="unhRequired">
					<xsl:with-param name="knoten" select="C_C517/D_3225"/>
					<xsl:with-param name="path" select="'SG4/SG5/S_LOC/C_C517/D_3225'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- **************************************************************************************  -->
	<!-- *****            SG6/RFF prüfen                                                    *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_UTILMD_SG4/G_UTILMD_SG6/S_RFF">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="C_C506/D_1153"/>
			<xsl:with-param name="list" select="'TN,ACW,AAV,AVE,Z07'"/>
			<xsl:with-param name="path" select="'SG4/SG6/RFF/1153'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_C506/D_1154"/>
			<xsl:with-param name="path" select="'SG4/SG6/RFF/1154'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
	</xsl:template>
	<!-- **************************************************************************************  -->
	<!-- *****          SG7/ S_CCI prüfen                                                    *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_UTILMD_SG4/G_UTILMD_SG7/S_CCI">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="C_C240/D_7037"/>
			<xsl:with-param name="path" select="'SG4/SG7/CCI/C240/7037'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="list" select="'E01,Z10,E02,E03,Y01,E17,Z12,Z15,Z18,Z17,Z35,Z36,Z37,Z38,Z39,Z40,Z41,Z42,Z43,Z44,Z45,Z46,Z47,Z48,Z49,Z50,Z51,Z52,Z53,Z54,Z55,Z56'"/>
			<xsl:with-param name="required" select="false()"/>
		</xsl:call-template>
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="D_7059"/>
			<xsl:with-param name="path" select="'SG4/SG7/CCI/7059'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="list" select="'Z02,Z03,Z04,Z05,Z06,Z07,Z12'"/>
			<xsl:with-param name="required" select="false()"/>
		</xsl:call-template>
		<xsl:if test="D_7059='Z06'">
			<xsl:call-template name="unhList">
				<xsl:with-param name="knoten" select="C_C240/D_7037"/>
				<xsl:with-param name="path" select="'SG4/SG7/CCI/C240/7037'"/>
				<xsl:with-param name="segment" select="$segment"/>
				<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				<xsl:with-param name="list" select="'Z35,Z36,Z37'"/>
				<xsl:with-param name="required" select="false()"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="D_7059='Z07'">
			<xsl:call-template name="unhList">
				<xsl:with-param name="knoten" select="C_C240/D_7037"/>
				<xsl:with-param name="path" select="'SG4/SG7/CCI/C240/7037'"/>
				<xsl:with-param name="segment" select="$segment"/>
				<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				<xsl:with-param name="list" select="'Z38,Z39,Z40,Z41,Z42,Z43,Z44,Z45,Z46,Z47,Z48,Z49,Z50,Z51,Z52,Z53,Z54,Z55,Z56'"/>
				<xsl:with-param name="required" select="false()"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="C_C240/D_7037='Z17'">
			<xsl:call-template name="unhList">
				<xsl:with-param name="knoten" select="C_C240/D_1131"/>
				<xsl:with-param name="path" select="'SG4/SG7/CCI/C240/1131'"/>
				<xsl:with-param name="segment" select="$segment"/>
				<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				<xsl:with-param name="list" select="'GABi-RLMNEV,GABi-RLMmT,GABi-RLMoT,Entry_H2,GABi-Entryso,GABi-Exitso,GABi-SLPana,GABi-SLPsyn,Entry_Biogas'"/>
				<xsl:with-param name="required" select="false()"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	<!-- **************************************************************************************  -->
	<!-- *****            SG7/S_CAV prüfen                                                    *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_UTILMD_SG4/G_UTILMD_SG7/S_CAV">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		<xsl:choose>
			<xsl:when test="../S_CCI/C_C240/D_7037='E01' or ../S_CCI/C_C240/D_7037='Z10'">
				<xsl:call-template name="unhRequired">
					<xsl:with-param name="knoten" select="C_C889/D_7111"/>
					<xsl:with-param name="path" select="'SG4/SG7/CAV/C889/7111'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:call-template>
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="C_C889/D_3055_1"/>
					<xsl:with-param name="path" select="'SG4/SG7/CAV/C889/3055'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					<xsl:with-param name="list" select="'89,293'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="../S_CCI/C_C240/D_7037='E02'">
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="C_C889/D_7111"/>
					<xsl:with-param name="path" select="'SG4/SG7/CAV/C889/7111'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					<xsl:with-param name="list" select="'E01,E02,E14,E24,Z29,Z36'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="../S_CCI/C_C240/D_7037='E03'">
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="C_C889/D_7111"/>
					<xsl:with-param name="path" select="'SG4/SG7/CAV/C889/7111'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					<xsl:with-param name="list" select="'E03,E04,E05,E06,E07,E08,E09'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="../S_CCI/C_C240/D_7037='Y01'">
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="C_C889/D_7111"/>
					<xsl:with-param name="path" select="'SG4/SG7/CAV/C889/7111'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					<xsl:with-param name="list" select="'Y01,Y02,Y03'"/>
				</xsl:call-template>
			</xsl:when>
			<!--			<xsl:when test="../S_CCI/C_C240/D_7037='E04'">
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="C_C889/D_7111"/>
					<xsl:with-param name="path" select="'SG4/SG7/CAV/C889/7111'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					<xsl:with-param name="list" select="'E03,E04,E05,E06'"/>
				</xsl:call-template>
			</xsl:when>
		
			<xsl:when test="../S_CCI/C_C240/D_7037='Z08' or ../S_CCI/C_C240/D_7037='Z09'">
				<xsl:call-template name="unhValue">
					<xsl:with-param name="knoten" select="C_C889/D_7111"/>
					<xsl:with-param name="path" select="'SG4/SG7/CAV/C889/7111'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					<xsl:with-param name="wert" select="'Z14'"/>
				</xsl:call-template>
			</xsl:when>
-->
			<xsl:when test="../S_CCI/C_C240/D_7037='E17'">
				<xsl:call-template name="unhValue">
					<xsl:with-param name="knoten" select="C_C889/D_7111"/>
					<xsl:with-param name="path" select="'SG4/SG7/CAV/C889/7111'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					<xsl:with-param name="wert" select="'Z22'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="../S_CCI/C_C240/D_7037='Z12'">
				<xsl:call-template name="unhRequired">
					<xsl:with-param name="knoten" select="C_C889/D_7111"/>
					<xsl:with-param name="path" select="'SG4/SG7/CAV/C889/7111'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:call-template>
			</xsl:when>
			<!--		<xsl:when test="../S_CCI/C_C240/D_7037='Z16'">
				<xsl:call-template name="unhValue">
					<xsl:with-param name="knoten" select="C_C889/D_7111"/>
					<xsl:with-param name="path" select="'SG4/SG7/CAV/C889/7111'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					<xsl:with-param name="wert" select="'Z28'"/>
				</xsl:call-template>
			</xsl:when>

			<xsl:when test="../S_CCI/C_C240/D_7037='Z21' or ../S_CCI/C_C240/D_7037='Z22' or ../S_CCI/C_C240/D_7037='Z23'">
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="C_C889/D_7111"/>
					<xsl:with-param name="path" select="'SG4/SG7/CAV/C889/7111'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					<xsl:with-param name="list" select="'ALP,EGZ,LGZ,NGZ,SEP,SLP,TEP,TLP,EGS,LGS,NZR,SES,SLS,TES,TLS,BAS,DBA,DZR,FPE,FPI,SRE,SRI,VZR,BIL,BIP,BIT,GAL,GAP,GAT,GEL,GEP,GET,SOL,SOP,SOT,WFL,WFP,WFT,WNL,WNP,WNT,WAL,WAP,WAT,BIO,GAS,GEO,SOS,WFO,WNO,WAS,XYZ'"/>
				</xsl:call-template>
			</xsl:when>					

-->

			<xsl:when test="../S_CCI/D_7059='Z02,Z03,Z04,Z05,Z12'">
				<xsl:call-template name="unhRequired">
					<xsl:with-param name="knoten" select="C_C889/D_7111"/>
					<xsl:with-param name="path" select="'SG4/SG7/CAV/C889/7111'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:call-template>
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="C_C889/D_3055_1"/>
					<xsl:with-param name="path" select="'SG4/SG7/CAV/C889/3055'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					<xsl:with-param name="list" select="'89,293'"/>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- **************************************************************************************  -->
	<!-- *****            S_SEQ prüfen                                                    *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_UTILMD_SG4/G_UTILMD_SG8/S_SEQ">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="D_1229"/>
			<xsl:with-param name="path" select="'SG4/SG8/SEQ/1229'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="list" select="'Z01,Z02,Z03,Z04,Z05,Z06,Z07,Z08,Z09,Z10'"/>
		</xsl:call-template>
	</xsl:template>
	<!-- **************************************************************************************  -->
	<!-- *****            SG8/S_RFF prüfen                                                    *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_UTILMD_SG4/G_UTILMD_SG8/S_RFF">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_C506/D_1154"/>
			<xsl:with-param name="path" select="'SG4/SG8/RFF/C506/1154'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		<xsl:choose>
			<xsl:when test="../S_SEQ/D_1229='Z01'">
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="C_C506/D_1153"/>
					<xsl:with-param name="path" select="'SG4/SG8/RFF/C506/1153'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					<xsl:with-param name="list" select="'AVE,AUU,Z12'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="../S_SEQ/D_1229='Z02'">
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="C_C506/D_1153"/>
					<xsl:with-param name="path" select="'SG4/SG8/RFF/C506/1153'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					<xsl:with-param name="list" select="'AVE,MG,Z11'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="../S_SEQ/D_1229='Z03'">
				<xsl:call-template name="unhValue">
					<xsl:with-param name="knoten" select="C_C506/D_1153"/>
					<xsl:with-param name="path" select="'SG4/SG8/RFF/C506/1153'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					<xsl:with-param name="wert" select="'AVE'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="../S_SEQ/D_1229='Z04' or ../S_SEQ/D_1229='Z05' or ../S_SEQ/D_1229='Z06' or ../S_SEQ/D_1229='Z09'">
				<xsl:call-template name="unhValue">
					<xsl:with-param name="knoten" select="C_C506/D_1153"/>
					<xsl:with-param name="path" select="'SG4/SG8/RFF/C506/1153'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					<xsl:with-param name="wert" select="'MG'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="../S_SEQ/D_1229='Z07'">
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="C_C506/D_1153"/>
					<xsl:with-param name="path" select="'SG4/SG8/RFF/C506/1153'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					<xsl:with-param name="list" select="'AVE,Z10'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="../S_SEQ/D_1229='Z10'">
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="C_C506/D_1153"/>
					<xsl:with-param name="path" select="'SG4/SG8/RFF/C506/1153'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					<xsl:with-param name="list" select="'AVE,Z10'"/>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- **************************************************************************************  -->
	<!-- *****            S_QTY prüfen                                                    *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="S_QTY">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		<xsl:variable name="kategorie" select="../../../../../M_UTILMD/S_BGM/C_C002/D_1001"/>
		<xsl:choose>
			<xsl:when test="../S_SEQ/D_1229='Z01'">
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="C_C186/D_6063"/>
					<xsl:with-param name="path" select="'SG4/SG8/SG9/QTY/C186/6063'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					<xsl:with-param name="list" select="'Z10,265,Z08,31,Y02,Z03,Z07,Z09,11'"/>
				</xsl:call-template>
				<xsl:choose>
					<xsl:when test="C_C186/D_6063='265'">
						<xsl:call-template name="unhValue">
							<xsl:with-param name="knoten" select="C_C186/D_6411"/>
							<xsl:with-param name="wert" select="'Z16'"/>
							<xsl:with-param name="path" select="'SG4/SG8/SG9/QTY/C186/6411 mit Qualifier 265'"/>
							<xsl:with-param name="segment" select="$segment"/>
							<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
							<xsl:with-param name="required" select="false()"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:when test="C_C186/D_6063='Z07' or C_C186/D_6063='Z08' or C_C186/D_6063='31' or C_C186/D_6063='Y02'  or C_C186/D_6063='Z09'">
						<xsl:call-template name="unhValue">
							<xsl:with-param name="knoten" select="C_C186/D_6411"/>
							<xsl:with-param name="wert" select="'KWH'"/>
							<xsl:with-param name="path" select="'SG4/SG8/SG9/QTY/C186/6411 mit Qualifier Z07, Z08, 31, Z09 oder Y02'"/>
							<xsl:with-param name="segment" select="$segment"/>
							<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
							<xsl:with-param name="required" select="false()"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:when test="C_C186/D_6063='Z03' or C_C186/D_6063='Z10'">
						<xsl:call-template name="unhValue">
							<xsl:with-param name="knoten" select="C_C186/D_6411"/>
							<xsl:with-param name="wert" select="'KWT'"/>
							<xsl:with-param name="path" select="'SG4/SG8/SG9/QTY/C186/6411 mit Qualifier Z03 oder Z10'"/>
							<xsl:with-param name="segment" select="$segment"/>
							<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
							<xsl:with-param name="required" select="false()"/>
						</xsl:call-template>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="($kategorie='Z05' and C_C186/D_6063='Z07') 
				or ($kategorie='Z05' and C_C186/D_6063='31') 
				or ($kategorie='Z05' and C_C186/D_6063='265')">
					<xsl:call-template name="unhRequired">
						<xsl:with-param name="knoten" select="C_C186/D_6060"/>
						<xsl:with-param name="path" select="'SG4/SG8/SG9/QTY/C186/6060'"/>
						<xsl:with-param name="segment" select="$segment"/>
						<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="C_C186/D_6063='11'">
					<xsl:call-template name="unhValue">
						<xsl:with-param name="knoten" select="C_C186/D_6411"/>
						<xsl:with-param name="path" select="'SG4/SG8/SG9/QTY/C186/6060'"/>
						<xsl:with-param name="segment" select="$segment"/>
						<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
						<xsl:with-param name="wert" select="'P1'"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<xsl:when test="../S_SEQ/D_1229='Z02'">
				<xsl:call-template name="unhValue">
					<xsl:with-param name="knoten" select="C_C186/D_6063"/>
					<xsl:with-param name="path" select="'SG4/SG8/SG9/QTY/C186/6063'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					<xsl:with-param name="wert" select="'79'"/>
				</xsl:call-template>
				<xsl:call-template name="unhValue">
					<xsl:with-param name="knoten" select="C_C186/D_6411"/>
					<xsl:with-param name="path" select="'SG4/SG8/SG9/QTY/C186/6411'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					<xsl:with-param name="wert" select="'KWH'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="../S_SEQ/D_1229='Z08'">
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="C_C186/D_6063"/>
					<xsl:with-param name="path" select="'SG4/SG8/SG9/QTY/C186/6063'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					<xsl:with-param name="list" select="'Z11,Z12,Z13,Z14,Z15'"/>
				</xsl:call-template>
				<xsl:call-template name="unhRequired">
					<xsl:with-param name="knoten" select="C_C186/D_6060"/>
					<xsl:with-param name="path" select="'SG4/SG8/SG9/QTY/C186/6060'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:call-template>
			</xsl:when>			
		</xsl:choose>
	</xsl:template>
	
	
	<!-- **************************************************************************************  -->
	<!-- *****            S_DTM in Segmentgruppe 9 prüfen                                 *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_UTILMD_SG9/S_DTM">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="C_C507/D_2005"/>
			<xsl:with-param name="path" select="'DTM/C507/2005'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="list" select="'163,164'"/>
		</xsl:call-template>

		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_C507/D_2380"/>
			<xsl:with-param name="path" select="'DTM/C507/2380'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>

		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="C_C507/D_2379"/>
			<xsl:with-param name="path" select="'DTM/C507/2379'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="wert" select="'203'"/>
		</xsl:call-template>
		
		<xsl:apply-templates select="C_C507" mode="qualifiersValid">
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:apply-templates>
		
		<xsl:apply-templates select="C_C507" mode="validateFormat">
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:apply-templates>
	</xsl:template>
	
	<xsl:template match="G_UTILMD_SG9/S_DTM/C_C507[D_2005='163' or D_2005='164']" mode="qualifiersValid" priority="10">
		<xsl:param name="segment"/>
		<xsl:param name="nachrichtID"/>
		
		<xsl:if test="D_2379 != '203'">
			<unh>
				<code>Z01</code>
				<freitext>
					<xsl:text>Feld SGDTM/C507/2379: falscher Datumsformat-Qualifier </xsl:text>
					<xsl:value-of select="D_2379"/>
					<xsl:text>fuer den Datumstyp 163 oder 164</xsl:text>
				</freitext>
				<segment><xsl:value-of select="$segment"/></segment>
				<referenz><xsl:value-of select="$nachrichtID"/></referenz>
			</unh>
		</xsl:if>
	</xsl:template>
	


	<!-- **************************************************************************************  -->
	<!-- *****            SG9/S_STS  prüfen                            								    *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_UTILMD_SG4/G_UTILMD_SG8/G_UTILMD_SG9/S_STS">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		<xsl:choose>
			<xsl:when test="../S_SEQ/D_1229='Z01'">
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="C_C601/D_9015"/>
					<xsl:with-param name="path" select="'SG4/STS/C601/9015'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					<xsl:with-param name="list" select="'5,Z16'"/>
				</xsl:call-template>
				<xsl:choose>
					<xsl:when test="C_C601/D_9015='5'">
						<xsl:call-template name="unhList">
							<xsl:with-param name="knoten" select="C_C556_1/D_9013"/>
							<xsl:with-param name="path" select="'SG4/STS/C556/9013'"/>
							<xsl:with-param name="segment" select="$segment"/>
							<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
							<xsl:with-param name="list" select="'Z18,Z19,Z20,Z21,Z22,Z23'"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:when test="C_C601/D_9015='Z16'">
						<xsl:call-template name="unhList">
							<xsl:with-param name="knoten" select="C_C556_1/D_9013"/>
							<xsl:with-param name="path" select="'SG4/STS/C556/9013'"/>
							<xsl:with-param name="segment" select="$segment"/>
							<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
							<xsl:with-param name="list" select="'Z24,Z25'"/>
						</xsl:call-template>
					</xsl:when>
				</xsl:choose>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- **************************************************************************************  -->
	<!-- *****          SG10/ S_CCI prüfen                                                    *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_UTILMD_SG4/G_UTILMD_SG8/G_UTILMD_SG10/S_CCI">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		<xsl:choose>
			<xsl:when test="../S_SEQ/D_1229='Z01'">
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="D_7059"/>
					<xsl:with-param name="list" select="'Z01,15'"/>
					<xsl:with-param name="path" select="'SG4/SG8/SG10/CCI/7059'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					<xsl:with-param name="required" select="false()"/>
				</xsl:call-template>
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="C_C240/D_7037"/>
					<xsl:with-param name="list" select="'Z30,Z31,Z32,Z21,E04,Z16,Z34'"/>
					<xsl:with-param name="path" select="'SG4/SG8/SG10/CCI/C240/7037'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:call-template>
				<xsl:if test="D_7059='15'">
					<xsl:call-template name="unhValue">
						<xsl:with-param name="knoten" select="C_C240/D_7037"/>
						<xsl:with-param name="path" select="'SG4/SG8/SG10/CCI/C240/7037'"/>
						<xsl:with-param name="segment" select="$segment"/>
						<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
						<xsl:with-param name="wert" select="'Z21'"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="D_7059='Z01'">
					<xsl:call-template name="unhList">
						<xsl:with-param name="knoten" select="C_C240/D_7037"/>
						<xsl:with-param name="path" select="'SG4/SG8/SG10/CCI/C240/7037'"/>
						<xsl:with-param name="segment" select="$segment"/>
						<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
						<xsl:with-param name="list" select="'Z30,Z31,Z32'"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<xsl:when test="../S_SEQ/D_1229='Z02'">
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="D_7059"/>
					<xsl:with-param name="list" select="'11,Z10'"/>
					<xsl:with-param name="path" select="'SG4/SG8/SG10/CCI/7059'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					<xsl:with-param name="required" select="false()"/>
				</xsl:call-template>
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="C_C240/D_7037"/>
					<xsl:with-param name="list" select="'Z33,Z59,Z60,Z63'"/>
					<xsl:with-param name="path" select="'SG4/SG8/SG10/CCI/C240/7037'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:call-template>
				<xsl:if test="D_7059='11'">
					<xsl:call-template name="unhValue">
						<xsl:with-param name="knoten" select="C_C240/D_7037"/>
						<xsl:with-param name="path" select="'SG4/SG8/SG10/CCI/C240/7037'"/>
						<xsl:with-param name="segment" select="$segment"/>
						<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
						<xsl:with-param name="wert" select="'Z33'"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="D_7037='Z63'">
					<xsl:call-template name="unhRequired">
						<xsl:with-param name="knoten" select="C_C240/D_7036"/>
						<xsl:with-param name="path" select="'SG4/SG8/SG10/CCI/C240/7036'"/>
						<xsl:with-param name="segment" select="$segment"/>
						<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					</xsl:call-template>
				</xsl:if>					
				<xsl:if test="D_7059='Z10'">
					<xsl:call-template name="unhList">
						<xsl:with-param name="knoten" select="C_C240/D_7037"/>
						<xsl:with-param name="path" select="'SG4/SG8/SG10/CCI/C240/7037'"/>
						<xsl:with-param name="segment" select="$segment"/>
						<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
						<xsl:with-param name="list" select="'Z59,Z60'"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<xsl:when test="../S_SEQ/D_1229='Z03'">
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="C_C240/D_7037"/>
					<xsl:with-param name="list" select="'E13,Z28,E12'"/>
					<xsl:with-param name="path" select="'SG4/SG8/SG10/CCI/C240/7037'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="../S_SEQ/D_1229='Z04'">
				<xsl:call-template name="unhValue">
					<xsl:with-param name="knoten" select="C_C240/D_7037"/>
					<xsl:with-param name="wert" select="'Z25'"/>
					<xsl:with-param name="path" select="'SG4/SG8/SG10/CCI/C240/7037'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="../S_SEQ/D_1229='Z05'">
				<xsl:call-template name="unhValue">
					<xsl:with-param name="knoten" select="C_C240/D_7037"/>
					<xsl:with-param name="wert" select="'Z26'"/>
					<xsl:with-param name="path" select="'SG4/SG8/SG10/CCI/C240/7037'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="../S_SEQ/D_1229='Z06'">
				<xsl:call-template name="unhValue">
					<xsl:with-param name="knoten" select="C_C240/D_7037"/>
					<xsl:with-param name="wert" select="'Z27'"/>
					<xsl:with-param name="path" select="'SG4/SG8/SG10/CCI/C240/7037'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="../S_SEQ/D_1229='Z07'">
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="C_C240/D_7037"/>
					<xsl:with-param name="list" select="'Z08,Z09'"/>
					<xsl:with-param name="path" select="'SG4/SG8/SG10/CCI/C240/7037'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:call-template>
			</xsl:when>		
			<xsl:when test="../S_SEQ/D_1229='Z08'">
				<xsl:call-template name="unhValue">
					<xsl:with-param name="knoten" select="D_7059"/>
					<xsl:with-param name="wert" select="'Z11'"/>
					<xsl:with-param name="path" select="'SG4/SG8/SG10/CCI/7059'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:call-template>
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="C_C240/D_7037"/>
					<xsl:with-param name="list" select="'Z61,Z62'"/>
					<xsl:with-param name="path" select="'SG4/SG8/SG10/CCI/C240/7037'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:call-template>				
			</xsl:when>					
			<xsl:when test="../S_SEQ/D_1229='Z09'">
				<xsl:call-template name="unhValue">
					<xsl:with-param name="knoten" select="C_C240/D_7037"/>
					<xsl:with-param name="wert" select="'Z64'"/>
					<xsl:with-param name="path" select="'SG4/SG8/SG10/CCI/C240/7037'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:call-template>
			</xsl:when>					
			<xsl:when test="../S_SEQ/D_1229='Z10'">
				<xsl:call-template name="unhValue">
					<xsl:with-param name="knoten" select="D_7059"/>
					<xsl:with-param name="wert" select="'Z13'"/>
					<xsl:with-param name="path" select="'SG4/SG8/SG10/CCI/7059'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:call-template>
				<xsl:if test="D_7059='Z13'">
					<xsl:call-template name="unhList">
						<xsl:with-param name="knoten" select="C_C240/D_7037"/>
						<xsl:with-param name="path" select="'SG4/SG8/SG10/CCI/C240/7037'"/>
						<xsl:with-param name="segment" select="$segment"/>
						<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
						<xsl:with-param name="list" select="'Z65,Z66'"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- **************************************************************************************  -->
	<!-- *****            SG10/S_CAV prüfen                                                    *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_UTILMD_SG4/G_UTILMD_SG8/G_UTILMD_SG10/S_CAV">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		<xsl:choose>
			<xsl:when test="../S_SEQ/D_1229='Z01'">
				<xsl:choose>
					<xsl:when test="../S_CCI/D_7059='15'">
						<xsl:call-template name="unhRequired">
							<xsl:with-param name="knoten" select="C_C889/D_7111"/>
							<xsl:with-param name="path" select="'SG4/SG8/SG10/CAV/C889/7111'"/>
							<xsl:with-param name="segment" select="$segment"/>
							<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:when test="../S_CCI/C_C240/D_7037='E04'">
						<xsl:call-template name="unhList">
							<xsl:with-param name="knoten" select="C_C889/D_7111"/>
							<xsl:with-param name="path" select="'SG4/SG8/SG10/CAV/C889/7111'"/>
							<xsl:with-param name="segment" select="$segment"/>
							<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
							<xsl:with-param name="list" select="'E03,E04,E05,E06'"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:when test="../S_CCI/C_C240/D_7037='Z16'">
						<xsl:call-template name="unhValue">
							<xsl:with-param name="knoten" select="C_C889/D_7111"/>
							<xsl:with-param name="path" select="'SG4/SG8/SG10/CAV/C889/7111'"/>
							<xsl:with-param name="segment" select="$segment"/>
							<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
							<xsl:with-param name="wert" select="'Z28'"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:when test="../S_CCI/C_C240/D_7037='Z34'">
						<xsl:call-template name="unhList">
							<xsl:with-param name="knoten" select="C_C889/D_7111"/>
							<xsl:with-param name="path" select="'SG4/SG8/SG10/CAV/C889/7111'"/>
							<xsl:with-param name="segment" select="$segment"/>
							<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
							<xsl:with-param name="list" select="'Z33,Z34,Z35'"/>
						</xsl:call-template>
					</xsl:when>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="../S_SEQ/D_1229='Z02'">
				<xsl:choose>
					<xsl:when test="../S_CCI/C_C240/D_7037='Z08' or ../S_CCI/C_C240/D_7037='Z09'">
						<xsl:call-template name="unhValue">
							<xsl:with-param name="knoten" select="C_C889/D_7111"/>
							<xsl:with-param name="path" select="'SG4/SG8/SG10/CAV/C889/7111'"/>
							<xsl:with-param name="segment" select="$segment"/>
							<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
							<xsl:with-param name="wert" select="'Z14'"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:when test="../S_CCI/C_C240/D_7037='Z33'">
						<xsl:call-template name="unhRequired">
							<xsl:with-param name="knoten" select="C_C889/D_7111"/>
							<xsl:with-param name="path" select="'SG4/SG8/SG10/CAV/C889/7110_1'"/>
							<xsl:with-param name="segment" select="$segment"/>
							<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
						</xsl:call-template>
						<xsl:call-template name="unhRequired">
							<xsl:with-param name="knoten" select="C_C889/D_7111"/>
							<xsl:with-param name="path" select="'SG4/SG8/SG10/CAV/C889/7110_2'"/>
							<xsl:with-param name="segment" select="$segment"/>
							<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
						</xsl:call-template>
					</xsl:when>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="../S_SEQ/D_1229='Z03'">
				<xsl:choose>
					<xsl:when test="../S_CCI/C_C240/D_7037='E13'">
						<xsl:call-template name="unhList">
							<xsl:with-param name="knoten" select="C_C889/D_7111"/>
							<xsl:with-param name="path" select="'SG4/SG8/SG10/CAV/C889/7111'"/>
							<xsl:with-param name="segment" select="$segment"/>
							<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
							<xsl:with-param name="list" select="'AHZ,WSZ,LAZ,EHZ,MAZ,DKZ,BGZ,TRZ,UGZ,WGZ,MRG,IVA,Z30,ETZ,ZTZ,NTZ,ERZ,ZRZ'"/>
						</xsl:call-template>
						<xsl:call-template name="unhList">
							<xsl:with-param name="knoten" select="C_C889/D_7110"/>
							<xsl:with-param name="path" select="'SG4/SG8/SG10/CAV/C889/7110'"/>
							<xsl:with-param name="segment" select="$segment"/>
							<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
							<xsl:with-param name="list" select="'G10,G100,G1000,G16,G160,G1600,G2.5,G25,G250,G2500,G4,G40,G400,G4000,G6,G65,G650,G6500,Z01,Z02,Z03'"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:when test="../S_CCI/C_C240/D_7037='Z28'">
						<xsl:call-template name="unhList">
							<xsl:with-param name="knoten" select="C_C889/D_7111"/>
							<xsl:with-param name="path" select="'SG4/SG8/SG10/CAV/C889/7111'"/>
							<xsl:with-param name="segment" select="$segment"/>
							<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
							<xsl:with-param name="list" select="'BKE,DPA,HUT,Z31,Z32'"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:when test="../S_CCI/C_C240/D_7037='E12'">
						<xsl:call-template name="unhList">
							<xsl:with-param name="knoten" select="C_C889/D_7111"/>
							<xsl:with-param name="path" select="'SG4/SG8/SG10/CAV/C889/7111'"/>
							<xsl:with-param name="segment" select="$segment"/>
							<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
							<xsl:with-param name="list" select="'AMR,MMR'"/>
						</xsl:call-template>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="C_C889/D_7111='Z30'">
					<xsl:call-template name="unhRequired">
						<xsl:with-param name="knoten" select="C_C889/D_7110"/>
						<xsl:with-param name="path" select="'SG4/SG8/SG10/CAV/C889/7110'"/>
						<xsl:with-param name="segment" select="$segment"/>
						<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<xsl:when test="../S_SEQ/D_1229='Z04'">
				<xsl:if test="../S_CCI/C_C240/D_7037='Z25'">
					<xsl:call-template name="unhList">
						<xsl:with-param name="knoten" select="C_C889/D_7111"/>
						<xsl:with-param name="path" select="'SG4/SG8/SG10/CAV/C889/7111'"/>
						<xsl:with-param name="segment" select="$segment"/>
						<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
						<xsl:with-param name="list" select="'Z30,MIW,MPW,MBW,MUW'"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="C_C889/D_7111='Z30'">
					<xsl:call-template name="unhRequired">
						<xsl:with-param name="knoten" select="C_C889/D_7110"/>
						<xsl:with-param name="path" select="'SG4/SG8/SG10/CAV/C889/7110'"/>
						<xsl:with-param name="segment" select="$segment"/>
						<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<xsl:when test="../S_SEQ/D_1229='Z05'">
				<xsl:if test="../S_CCI/C_C240/D_7037='Z26'">
					<xsl:call-template name="unhList">
						<xsl:with-param name="knoten" select="C_C889/D_7111"/>
						<xsl:with-param name="path" select="'SG4/SG8/SG10/CAV/C889/7111'"/>
						<xsl:with-param name="segment" select="$segment"/>
						<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
						<xsl:with-param name="list" select="'Z30,GSM,ETH,PLC,PST'"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="C_C889/D_7111='Z30'">
					<xsl:call-template name="unhRequired">
						<xsl:with-param name="knoten" select="C_C889/D_7110"/>
						<xsl:with-param name="path" select="'SG4/SG8/SG10/CAV/C889/7110'"/>
						<xsl:with-param name="segment" select="$segment"/>
						<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<xsl:when test="../S_SEQ/D_1229='Z06'">
				<xsl:if test="../S_CCI/C_C240/D_7037='Z27'">
					<xsl:call-template name="unhList">
						<xsl:with-param name="knoten" select="C_C889/D_7111"/>
						<xsl:with-param name="path" select="'SG4/SG8/SG10/CAV/C889/7111'"/>
						<xsl:with-param name="segment" select="$segment"/>
						<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
						<xsl:with-param name="list" select="'Z30,RSU,TSU'"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="C_C889/D_7111='Z30'">
					<xsl:call-template name="unhRequired">
						<xsl:with-param name="knoten" select="C_C889/D_7110"/>
						<xsl:with-param name="path" select="'SG4/SG8/SG10/CAV/C889/7110'"/>
						<xsl:with-param name="segment" select="$segment"/>
						<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<xsl:when test="../S_SEQ/D_1229='Z07'">
				<xsl:if test="../S_CCI/C_C240/D_7037='Z08' or ../S_CCI/C_C240/D_7037='Z09'">
					<xsl:call-template name="unhList">
						<xsl:with-param name="knoten" select="C_C889/D_7111"/>
						<xsl:with-param name="path" select="'SG4/SG8/SG10/CAV/C889/7111'"/>
						<xsl:with-param name="segment" select="$segment"/>
						<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
						<xsl:with-param name="list" select="'KAS,SA,SAS,TA,TAS,TK,TKS,TS,TSS'"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="C_C889/D_7111='Z30'">
					<xsl:call-template name="unhRequired">
						<xsl:with-param name="knoten" select="C_C889/D_7110"/>
						<xsl:with-param name="path" select="'SG4/SG8/SG10/CAV/C889/7110'"/>
						<xsl:with-param name="segment" select="$segment"/>
						<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<xsl:when test="../S_SEQ/D_1229='Z09'">
				<xsl:if test="../S_CCI/C_C240/D_7037='Z64'">
					<xsl:call-template name="unhList">
						<xsl:with-param name="knoten" select="C_C889/D_7111"/>
						<xsl:with-param name="path" select="'SG4/SG8/SG10/CAV/C889/7111'"/>
						<xsl:with-param name="segment" select="$segment"/>
						<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
						<xsl:with-param name="list" select="'Z30,DMU,TMU,ZMU'"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="C_C889/D_7111='Z30'">
					<xsl:call-template name="unhRequired">
						<xsl:with-param name="knoten" select="C_C889/D_7110"/>
						<xsl:with-param name="path" select="'SG4/SG8/SG10/CAV/C889/7110'"/>
						<xsl:with-param name="segment" select="$segment"/>
						<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>			
		</xsl:choose>
	</xsl:template>
	<!-- **************************************************************************************  -->
	<!-- *****            S_PIA prüfen                                                    *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="S_PIA">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		
		<xsl:choose>
			<xsl:when test="../S_SEQ/D_1229='Z02'">

				<xsl:call-template name="unhValue">
					<xsl:with-param name="knoten" select="D_4347"/>
					<xsl:with-param name="wert" select="'5'"/>
					<xsl:with-param name="path" select="'SG4/SG8/PIA/4347'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:call-template>
				
				<xsl:apply-templates select="C_C212_1">
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:apply-templates>
	
				
			</xsl:when>
			<xsl:when test="../S_SEQ/D_1229='Z08'">

				<xsl:call-template name="unhValue">
					<xsl:with-param name="knoten" select="D_4347"/>
					<xsl:with-param name="wert" select="'Z01'"/>
					<xsl:with-param name="path" select="'SG4/SG8/PIA/4347'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:call-template>
				
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="C_C212_1/D_7143_1"/>
					<xsl:with-param name="list" select="'Z03,Z04,Z05'"/>
					<xsl:with-param name="path" select="'SG4/SG8/PIA/C212/7143'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:call-template>
				
			</xsl:when>			
		</xsl:choose>		
			
	</xsl:template>
		
		
		
	<xsl:template match="S_PIA/C_C212_1">
		<xsl:param name="segment" as="xs:integer"/>
		<xsl:param name="nachrichtID"/>

		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="D_7140_1"/>
			<xsl:with-param name="path" select="'SG4/SG8/PIA/C212/7140 (erstes C212)'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>

		<xsl:call-template name="unhValue">
			<xsl:with-param name="knoten" select="D_7143_1"/>
			<xsl:with-param name="wert" select="'SRW'"/>
			<xsl:with-param name="path" select="'SG4/SG8/PIA/C212/7143 (erstes C212)'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
	</xsl:template>

	<!-- **************************************************************************************  -->
	<!-- *****           S_NAD unter der SG12 prüfen                       *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_UTILMD_SG12/S_NAD">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="D_3035"/>
			<xsl:with-param name="path" select="'SG2/NAD/3035'"/>
			<xsl:with-param name="list" select="'UD,EO,DEB.DDE,SU,VY,DP,Z03'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		<xsl:choose>
			<xsl:when test="D_3035='UD' or D_3035='EO'">
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="C_C080/D_3045"/>
					<xsl:with-param name="path" select="'SG2/NAD/C080/3045'"/>
					<xsl:with-param name="list" select="'Z01,Z02'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					<xsl:with-param name="required" select="false()"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="D_3035='DEB' or D_3035='DDE' or D_3035='VY' or D_3035='SU'">
				<xsl:call-template name="unhRequired">
					<xsl:with-param name="knoten" select="C_C082/D_3039"/>
					<xsl:with-param name="path" select="'SG2/NAD/C082/3039'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:call-template>
				<xsl:call-template name="unhList">
					<xsl:with-param name="knoten" select="C_C082/D_3055"/>
					<xsl:with-param name="path" select="'SG2/NAD/C082/3055'"/>
					<xsl:with-param name="list" select="'9,293,332'"/>
					<xsl:with-param name="segment" select="$segment"/>
					<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- **************************************************************************************  -->
	<!-- *****            SG12/S_RFF prüfen                                                    *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="G_UTILMD_SG4/G_UTILMD_SG12/S_RFF">
		<xsl:param name="segment" as="xs:integer" select="position()"/>
		<xsl:param name="nachrichtID"/>
		<xsl:call-template name="unhRequired">
			<xsl:with-param name="knoten" select="C_C506/D_1154"/>
			<xsl:with-param name="path" select="'SG4/SG8/RFF/C506/1154'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
		</xsl:call-template>
		<xsl:call-template name="unhList">
			<xsl:with-param name="knoten" select="C_C506/D_1153"/>
			<xsl:with-param name="path" select="'SG4/SG8/RFF/C506/1153'"/>
			<xsl:with-param name="segment" select="$segment"/>
			<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
			<xsl:with-param name="list" select="'AVC,Z01,Z05,AVE,MG'"/>
		</xsl:call-template>
		<xsl:if test="C_C506/D_1153='Z05'">
			<xsl:call-template name="unhList">
				<xsl:with-param name="knoten" select="C_C506/D_1154"/>
				<xsl:with-param name="path" select="'SG4/SG8/RFF/C506/1154'"/>
				<xsl:with-param name="segment" select="$segment"/>
				<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
				<xsl:with-param name="list" select="'JA,NEIN'"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	<!-- **************************************************************************************  -->
	<!-- *****            S_UNT wird nicht näher geprüft                                  *****  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="S_UNT"/>
	<!-- **************************************************************************************  -->
	<!-- **************************************************************************************  -->
	<!-- *****                                                                            *****  -->
	<!-- *****                     Transformations-Funktionen                             *****  -->
	<!-- *****                                                                            *****  -->
	<!-- **************************************************************************************  -->
	<!-- **************************************************************************************  -->
	<xsl:template name="unbValue">
		<xsl:param name="knoten" required="yes"/>
		<xsl:param name="wert" required="yes"/>
		<xsl:param name="path" required="yes" as="xs:string"/>
		<xsl:param name="required" required="no" as="xs:boolean" select="true()"/>
		<xsl:choose>
			<xsl:when test="$knoten">
				<xsl:if test="$knoten != $wert">
					<unb>
						<code>Z01</code>
						<freitext>
							<xsl:text>Feld </xsl:text>
							<xsl:value-of select="$path"/>
							<xsl:text> muss </xsl:text>
							<xsl:value-of select="$wert"/>
							<xsl:text> lauten, ist aber </xsl:text>
							<xsl:value-of select="$knoten"/>
						</freitext>
					</unb>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="$required">
					<xsl:call-template name="unbRequired">
						<xsl:with-param name="knoten" select="$knoten"/>
						<xsl:with-param name="path" select="$path"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="unbList">
		<xsl:param name="knoten" required="yes"/>
		<xsl:param name="path" required="yes" as="xs:string"/>
		<xsl:param name="list" required="yes" as="xs:string"/>
		<xsl:param name="required" required="no" as="xs:boolean" select="true()"/>
		<xsl:choose>
			<xsl:when test="$knoten">
				<xsl:if test="not(exists(tokenize($list, ',')[. = $knoten]))">
					<unb>
						<code>Z01</code>
						<freitext>
							<xsl:text>Feld </xsl:text>
							<xsl:value-of select="$path"/>
							<xsl:text> muss </xsl:text>
							<xsl:value-of select="$list"/>
							<xsl:text> lauten, ist aber </xsl:text>
							<xsl:value-of select="$knoten"/>
						</freitext>
					</unb>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="$required">
					<xsl:call-template name="unbRequired">
						<xsl:with-param name="knoten" select="$knoten"/>
						<xsl:with-param name="path" select="$path"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="unbRequired">
		<xsl:param name="knoten" required="yes"/>
		<xsl:param name="path" required="yes" as="xs:string"/>
		<xsl:if test="not($knoten)">
			<unb>
				<code>Z03</code>
				<freitext>
					<xsl:text>Feld </xsl:text>
					<xsl:value-of select="$path"/>
					<xsl:text> fehlt</xsl:text>
				</freitext>
			</unb>
		</xsl:if>
	</xsl:template>
	<xsl:template name="unbIsDate">
		<xsl:param name="knoten" required="yes"/>
		<xsl:param name="path" required="yes" as="xs:string"/>
		<xsl:choose>
			<xsl:when test="$knoten">
				<xsl:variable name="formatted">
					<xsl:text>20</xsl:text>
					<xsl:value-of select="substring($knoten, 1, 2)"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="substring($knoten, 3, 2)"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="substring($knoten, 5, 2)"/>
				</xsl:variable>
				<xsl:if test="not($formatted castable as xs:date)">
					<unb>
						<code>Z02</code>
						<freitext>
							<xsl:text>Feld </xsl:text>
							<xsl:value-of select="$path"/>
							<xsl:text> entspricht nicht dem Datumsformat YYMMDD: </xsl:text>
							<xsl:value-of select="$knoten"/>
						</freitext>
					</unb>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="unbRequired">
					<xsl:with-param name="knoten" select="$knoten"/>
					<xsl:with-param name="path" select="$path"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="unbIsTime">
		<xsl:param name="knoten" required="yes"/>
		<xsl:param name="path" required="yes" as="xs:string"/>
		<xsl:choose>
			<xsl:when test="$knoten">
				<xsl:variable name="formatted">
					<xsl:value-of select="substring($knoten, 1, 2)"/>
					<xsl:text>:</xsl:text>
					<xsl:value-of select="substring($knoten, 3, 2)"/>
					<xsl:text>:00</xsl:text>
				</xsl:variable>
				<xsl:if test="not($formatted castable as xs:time)">
					<unb>
						<code>Z02</code>
						<freitext>
							<xsl:text>Feld </xsl:text>
							<xsl:value-of select="$path"/>
							<xsl:text> entspricht nicht dem Zeitformat HHMM: </xsl:text>
							<xsl:value-of select="$knoten"/>
						</freitext>
					</unb>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="unbRequired">
					<xsl:with-param name="knoten" select="$knoten"/>
					<xsl:with-param name="path" select="$path"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="unhValue">
		<xsl:param name="knoten" required="yes"/>
		<xsl:param name="wert" required="yes"/>
		<xsl:param name="path" required="yes" as="xs:string"/>
		<xsl:param name="required" required="no" as="xs:boolean" select="true()"/>
		<xsl:param name="segment" as="xs:integer" required="yes"/>
		<xsl:param name="nachrichtID" required="yes"/>
		<xsl:choose>
			<xsl:when test="$knoten">
				<xsl:if test="$knoten != $wert">
					<unh>
						<code>Z01</code>
						<freitext>
							<xsl:text>Feld </xsl:text>
							<xsl:value-of select="$path"/>
							<xsl:text> muss </xsl:text>
							<xsl:value-of select="$wert"/>
							<xsl:text> lauten, ist aber </xsl:text>
							<xsl:value-of select="$knoten"/>
						</freitext>
						<segment>
							<xsl:value-of select="$segment"/>
						</segment>
						<referenz>
							<xsl:value-of select="$nachrichtID"/>
						</referenz>
					</unh>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="$required">
					<xsl:call-template name="unhRequired">
						<xsl:with-param name="knoten" select="$knoten"/>
						<xsl:with-param name="path" select="$path"/>
						<xsl:with-param name="segment" select="$segment"/>
						<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="unhList">
		<xsl:param name="knoten" required="yes"/>
		<xsl:param name="path" required="yes" as="xs:string"/>
		<xsl:param name="list" required="yes" as="xs:string"/>
		<xsl:param name="segment" as="xs:integer" required="yes"/>
		<xsl:param name="nachrichtID" required="yes"/>
		<xsl:param name="required" required="no" as="xs:boolean" select="true()"/>
		<xsl:choose>
			<xsl:when test="$knoten">
				<xsl:if test="not(exists(tokenize($list, ',')[. = $knoten]))">
					<unh>
						<code>Z01</code>
						<freitext>
							<xsl:text>Feld </xsl:text>
							<xsl:value-of select="$path"/>
							<xsl:text> muss einen der Werte </xsl:text>
							<xsl:value-of select="$list"/>
							<xsl:text> haben, ist aber </xsl:text>
							<xsl:value-of select="$knoten"/>
						</freitext>
						<segment>
							<xsl:value-of select="$segment"/>
						</segment>
						<referenz>
							<xsl:value-of select="$nachrichtID"/>
						</referenz>
					</unh>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="$required">
					<xsl:call-template name="unhRequired">
						<xsl:with-param name="knoten" select="$knoten"/>
						<xsl:with-param name="path" select="$path"/>
						<xsl:with-param name="segment" select="$segment"/>
						<xsl:with-param name="nachrichtID" select="$nachrichtID"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="unhRequired">
		<xsl:param name="knoten" required="yes"/>
		<xsl:param name="path" required="yes" as="xs:string"/>
		<xsl:param name="segment" as="xs:integer" required="yes"/>
		<xsl:param name="nachrichtID" required="yes"/>
		<xsl:choose>
			<xsl:when test="$knoten">
				<xsl:if test="$knoten castable as xs:string">
					<xsl:variable name="asString" select="$knoten" as="xs:string"/>
					<xsl:if test="$asString = ''">
						<unh>
							<code>Z03</code>
							<freitext>
								<xsl:text>Feld </xsl:text>
								<xsl:value-of select="$path"/>
								<xsl:text> ist leer</xsl:text>
							</freitext>
							<segment>
								<xsl:value-of select="$segment"/>
							</segment>
							<referenz>
								<xsl:value-of select="$nachrichtID"/>
							</referenz>
						</unh>
					</xsl:if>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<unh>
					<code>Z03</code>
					<freitext>
						<xsl:text>Feld </xsl:text>
						<xsl:value-of select="$path"/>
						<xsl:text> fehlt</xsl:text>
					</freitext>
					<segment>
						<xsl:value-of select="$segment"/>
					</segment>
					<referenz>
						<xsl:value-of select="$nachrichtID"/>
					</referenz>
				</unh>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- **************************************************************************************  -->
	<!-- **************************************************************************************  -->
	<!-- *****                                                                            *****  -->
	<!-- *****                     Validierung von Datumsformaten                         *****  -->
	<!-- *****                                                                            *****  -->
	<!-- **************************************************************************************  -->
	<!-- **************************************************************************************  -->
	<xsl:template match="S_DTM/C_C507[D_2379='303']" mode="validateFormat" priority="10">
		<xsl:param name="segment" required="yes"/>
		<xsl:param name="nachrichtID" required="yes"/>
		<xsl:choose>
			<xsl:when test="string-length(D_2380) &gt; 14">
				<xsl:variable name="zeitzone1" select="substring(D_2380, 13)"/>
				<xsl:variable name="zeitzone">
					<xsl:choose>
						<xsl:when test="substring($zeitzone1, 1, 1) = '?'">
							<xsl:value-of select="substring($zeitzone1, 2)"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$zeitzone1"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<xsl:variable name="datumAsString">
					<xsl:value-of select="substring(D_2380, 1, 4)"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="substring(D_2380, 5, 2)"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="substring(D_2380, 7, 2)"/>
					<xsl:text>T</xsl:text>
					<xsl:value-of select="substring(D_2380, 9, 2)"/>
					<xsl:text>:</xsl:text>
					<xsl:value-of select="substring(D_2380, 11, 2)"/>
					<xsl:text>:00.000</xsl:text>
					<xsl:value-of select="$zeitzone"/>
					<xsl:text>:00</xsl:text>
				</xsl:variable>
				<xsl:choose>
					<xsl:when test="$datumAsString castable as xs:dateTime"/>
					<xsl:otherwise>
						<unh>
							<code>Z02</code>
							<freitext>
								<xsl:text>Feld DTM/C507/2380 entspricht nicht dem Datumsformat</xsl:text>
								<xsl:text> 303 - CCYYMMDDHHMMZZZ: </xsl:text>
								<xsl:value-of select="D_2380"/>
							</freitext>
							<segment>
								<xsl:value-of select="$segment"/>
							</segment>
							<referenz>
								<xsl:value-of select="$nachrichtID"/>
							</referenz>
						</unh>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<unh>
					<code>Z03</code>
					<freitext>Feld DTM/C507/2380 fehlt oder zu wenig Zeichen fuer Datumsformat 203 - CCYYMMDDHHMMZZZ</freitext>
					<segment>
						<xsl:value-of select="$segment"/>
					</segment>
					<referenz>
						<xsl:value-of select="$nachrichtID"/>
					</referenz>
				</unh>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="S_DTM/C_C507[D_2379='203']" mode="validateFormat" priority="10">
		<xsl:param name="segment" required="yes"/>
		<xsl:param name="nachrichtID" required="yes"/>
		<xsl:choose>
			<xsl:when test="string-length(D_2380) &gt; 11">
				<xsl:variable name="datumAsString">
					<xsl:value-of select="substring(D_2380, 1, 4)"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="substring(D_2380, 5, 2)"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="substring(D_2380, 7, 2)"/>
					<xsl:text>T</xsl:text>
					<xsl:value-of select="substring(D_2380, 9, 2)"/>
					<xsl:text>:</xsl:text>
					<xsl:value-of select="substring(D_2380, 11, 2)"/>
					<xsl:text>:00.000</xsl:text>
				</xsl:variable>
				<xsl:choose>
					<xsl:when test="$datumAsString castable as xs:dateTime"/>
					<xsl:otherwise>
						<unh>
							<code>Z02</code>
							<freitext>Feld DTM/C507/2380 entspricht nicht dem Datumsformat 203 - CCYYMMDDHHMM</freitext>
							<segment>
								<xsl:value-of select="$segment"/>
							</segment>
							<referenz>
								<xsl:value-of select="$nachrichtID"/>
							</referenz>
						</unh>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<unh>
					<code>Z03</code>
					<freitext>Feld DTM/C507/2380 fehlt oder zu wenig Zeichen fuer Datumsformat 203 - CCYYMMDDHHMM</freitext>
					<segment>
						<xsl:value-of select="$segment"/>
					</segment>
					<referenz>
						<xsl:value-of select="$nachrichtID"/>
					</referenz>
				</unh>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="S_DTM/C_C507[D_2379='204']" mode="validateFormat" priority="10">
		<xsl:param name="segment" required="yes"/>
		<xsl:param name="nachrichtID" required="yes"/>
		<xsl:choose>
			<xsl:when test="string-length(D_2380) &gt; 13">
				<xsl:variable name="datumAsString">
					<xsl:value-of select="substring(D_2380, 1, 4)"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="substring(D_2380, 5, 2)"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="substring(D_2380, 7, 2)"/>
					<xsl:text>T</xsl:text>
					<xsl:value-of select="substring(D_2380, 9, 2)"/>
					<xsl:text>:</xsl:text>
					<xsl:value-of select="substring(D_2380, 11, 2)"/>
					<xsl:text>:</xsl:text>
					<xsl:value-of select="substring(D_2380, 13, 2)"/>
					<xsl:text>.000</xsl:text>
				</xsl:variable>
				<xsl:choose>
					<xsl:when test="$datumAsString castable as xs:dateTime"/>
					<xsl:otherwise>
						<unh>
							<code>Z02</code>
							<freitext>Feld DTM/C507/2380 entspricht nicht dem Datumsformat 204 - CCYYMMDDHHMMSS</freitext>
							<segment>
								<xsl:value-of select="$segment"/>
							</segment>
							<referenz>
								<xsl:value-of select="$nachrichtID"/>
							</referenz>
						</unh>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<unh>
					<code>Z03</code>
					<freitext>Feld DTM/C507/2380 fehlt oder zu wenig Zeichen fuer Datumsformat 204 - CCYYMMDDHHMMSS</freitext>
					<segment>
						<xsl:value-of select="$segment"/>
					</segment>
					<referenz>
						<xsl:value-of select="$nachrichtID"/>
					</referenz>
				</unh>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="S_DTM/C_C507[D_2379='102']" mode="validateFormat" priority="10">
		<xsl:param name="segment" required="yes"/>
		<xsl:param name="nachrichtID" required="yes"/>
		<xsl:choose>
			<xsl:when test="string-length(D_2380) &gt; 7">
				<xsl:variable name="datumAsString">
					<xsl:value-of select="substring(D_2380, 1, 4)"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="substring(D_2380, 5, 2)"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="substring(D_2380, 7, 2)"/>
				</xsl:variable>
				<xsl:choose>
					<xsl:when test="$datumAsString castable as xs:date"/>
					<xsl:otherwise>
						<unh>
							<code>Z02</code>
							<freitext>Feld DTM/C507/2380 entspricht nicht dem Datumsformat 102 - CCYYMMDD</freitext>
							<segment>
								<xsl:value-of select="$segment"/>
							</segment>
							<referenz>
								<xsl:value-of select="$nachrichtID"/>
							</referenz>
						</unh>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<unh>
					<code>Z03</code>
					<freitext>Feld DTM/C507/2380 fehlt oder zu wenig Zeichen fuer Datumsformat 102 - CCYYMMDD</freitext>
					<segment>
						<xsl:value-of select="$segment"/>
					</segment>
					<referenz>
						<xsl:value-of select="$nachrichtID"/>
					</referenz>
				</unh>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="S_DTM/C_C507[D_2379='806']" mode="validateFormat" priority="10">
		<xsl:param name="segment" required="yes"/>
		<xsl:param name="nachrichtID" required="yes"/>
		<xsl:choose>
			<xsl:when test="string-length(D_2380) &gt; 0">
				<xsl:choose>
					<xsl:when test="D_2380 castable as xs:integer">
						<xsl:variable name="asInt" as="xs:integer" select="D_2380"/>
						<xsl:if test="$asInt &lt; 0 or $asInt &gt; 59">
							<unh>
								<code>Z02</code>
								<freitext>
									<xsl:text>Feld DTM/C507/2380 ist keine Minute: </xsl:text>
									<xsl:value-of select="$asInt"/>
								</freitext>
								<segment>
									<xsl:value-of select="$segment"/>
								</segment>
								<referenz>
									<xsl:value-of select="$nachrichtID"/>
								</referenz>
							</unh>
						</xsl:if>
					</xsl:when>
					<xsl:otherwise>
						<unh>
							<code>Z02</code>
							<freitext>Feld DTM/C507/2380 entspricht nicht dem Datumsformat 806 - Minuten</freitext>
							<segment>
								<xsl:value-of select="$segment"/>
							</segment>
							<referenz>
								<xsl:value-of select="$nachrichtID"/>
							</referenz>
						</unh>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<unh>
					<code>Z03</code>
					<freitext>Feld DTM/C507/2380 fehlt oder zu wenig Zeichen fuer Datumsformat 806 - Minuten</freitext>
					<segment>
						<xsl:value-of select="$segment"/>
					</segment>
					<referenz>
						<xsl:value-of select="$nachrichtID"/>
					</referenz>
				</unh>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="S_DTM/C_C507[D_2379='610']" mode="validateFormat" priority="10">
		<xsl:param name="segment" required="yes"/>
		<xsl:param name="nachrichtID" required="yes"/>
		<xsl:choose>
			<xsl:when test="string-length(D_2380) &gt; 5">
				<xsl:variable name="datumAsString">
					<xsl:value-of select="substring(D_2380, 1, 4)"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="substring(D_2380, 5, 2)"/>
					<xsl:text>-01</xsl:text>
				</xsl:variable>
				<xsl:choose>
					<xsl:when test="$datumAsString castable as xs:date"/>
					<xsl:otherwise>
						<unh>
							<code>Z02</code>
							<freitext>Feld DTM/C507/2380 entspricht nicht dem Datumsformat 610 - CCYYMM</freitext>
							<segment>
								<xsl:value-of select="$segment"/>
							</segment>
							<referenz>
								<xsl:value-of select="$nachrichtID"/>
							</referenz>
						</unh>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<unh>
					<code>Z03</code>
					<freitext>Feld DTM/C507/2380 fehlt oder zu wenig Zeichen fuer Datumsformat 610 - CCYYMM</freitext>
					<segment>
						<xsl:value-of select="$segment"/>
					</segment>
					<referenz>
						<xsl:value-of select="$nachrichtID"/>
					</referenz>
				</unh>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="S_DTM/C_C507[D_2379='406']" mode="validateFormat" priority="10">
		<xsl:param name="segment"/>
		<xsl:param name="nachrichtID"/>
		<xsl:choose>
			<xsl:when test="not(D_2380) or (concat(substring(D_2380, 2, 2), ':', substring(D_2380, 4, 2), ':00') castable as xs:time 
			and string-length(D_2380)=5 and (substring(D_2380, 1, 1) = '+' or substring(D_2380, 1, 1) = '-'))"/>
			<xsl:otherwise>
				<unh>
					<code>Z02</code>
					<freitext>
						<xsl:text>Feld DTM/C507/2380 entspricht nicht dem Datumsformat 406 - ZHHMM: </xsl:text>
						<xsl:value-of select="D_2380"/>
					</freitext>
					<segment>
						<xsl:value-of select="$segment"/>
					</segment>
					<referenz>
						<xsl:value-of select="$nachrichtID"/>
					</referenz>
				</unh>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="S_DTM/C_C507[D_2379='106']" mode="validateFormat" priority="10">
		<xsl:param name="segment"/>
		<xsl:param name="nachrichtID"/>
		<xsl:choose>
			<xsl:when test="number(D_2380) and string-length(D_2380)=4"/>
			<xsl:otherwise>
				<unh>
					<code>Z02</code>
					<freitext>
						<xsl:text>Feld DTM/C507/2380 entspricht nicht dem Datumsformat 106 - CCYY: </xsl:text>
						<xsl:value-of select="D_2380"/>
					</freitext>
					<segment>
						<xsl:value-of select="$segment"/>
					</segment>
					<referenz>
						<xsl:value-of select="$nachrichtID"/>
					</referenz>
				</unh>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="S_DTM/C_C507[D_2379='104']" mode="validateFormat" priority="10">
		<xsl:param name="segment"/>
		<xsl:param name="nachrichtID"/>
		<xsl:choose>
			<xsl:when test="string-length(D_2380)=8"/>
			<xsl:otherwise>
				<unh>
					<code>Z02</code>
					<freitext>
						<xsl:text>Feld DTM/C507/2380 entspricht nicht dem Datumsformat 104 - MMWWMMWW: </xsl:text>
						<xsl:value-of select="D_2380"/>
					</freitext>
					<segment>
						<xsl:value-of select="$segment"/>
					</segment>
					<referenz>
						<xsl:value-of select="$nachrichtID"/>
					</referenz>
				</unh>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="S_DTM/C_C507[D_2379='802']" mode="validateFormat" priority="10">
		<xsl:param name="segment"/>
		<xsl:param name="nachrichtID"/>
		<xsl:choose>
			<xsl:when test="number(D_2380)"/>
			<xsl:otherwise>
				<unh>
					<code>Z02</code>
					<freitext>
						<xsl:text>Feld DTM/C507/2380 entspricht nicht dem Datumsformat 104 - MMWW-MMWW: </xsl:text>
						<xsl:value-of select="D_2380"/>
					</freitext>
					<segment>
						<xsl:value-of select="$segment"/>
					</segment>
					<referenz>
						<xsl:value-of select="$nachrichtID"/>
					</referenz>
				</unh>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="S_DTM/C_C507" mode="validateFormat" priority="5">
		<xsl:param name="segment" required="yes"/>
		<xsl:param name="nachrichtID" required="yes"/>
		<xsl:message terminate="yes">
			<xsl:text>Unberücksichtigtes Format in "validateFormat": </xsl:text>
			<xsl:value-of select="D_2379"/>
			<xsl:text> in Referenz </xsl:text>
			<xsl:value-of select="$nachrichtID"/>
			<xsl:text> Segment </xsl:text>
			<xsl:value-of select="$segment"/>
		</xsl:message>
	</xsl:template>
</xsl:stylesheet>
